@@ -764,12 +764,12 @@ static int kill_sectors() {
 static void commit_disks(commit_phase_t phase) {
 
 	int rc = 0;
-	list_element_t iter;
+	list_element_t iter, iter2;
 	storage_object_t * disk;
 
 	LOG_PROC_ENTRY();
 
-	LIST_FOR_EACH(&disks_list, iter, disk) {
+	LIST_FOR_EACH_SAFE(&disks_list, iter, iter2, disk) {
 		if ((disk->flags & SOFLAG_DIRTY) &&
 		    (disk->plugin != NULL) &&
 		    (disk->plugin->functions.plugin != NULL)) {
@@ -797,12 +797,12 @@ static void commit_disks(commit_phase_t phase) {
 static void commit_segments(commit_phase_t phase) {
 
 	int rc = 0;
-	list_element_t iter;
+	list_element_t iter, iter2;
 	storage_object_t * segment;
 
 	LOG_PROC_ENTRY();
 
-	LIST_FOR_EACH(&segments_list, iter, segment) {
+	LIST_FOR_EACH_SAFE(&segments_list, iter, iter2, segment) {
 		if ((segment->flags & SOFLAG_DIRTY) &&
 		    (segment->plugin != NULL) &&
 		    (segment->plugin->functions.plugin != NULL)) {
@@ -830,12 +830,12 @@ static void commit_segments(commit_phase_t phase) {
 static void commit_containers(commit_phase_t phase) {
 
 	int rc = 0;
-	list_element_t iter;
+	list_element_t iter, iter2;
 	storage_container_t * con;
 
 	LOG_PROC_ENTRY();
 
-	LIST_FOR_EACH(&containers_list, iter, con) {
+	LIST_FOR_EACH_SAFE(&containers_list, iter, iter2, con) {
 		if ((con->flags & SCFLAG_DIRTY) &&
 		    (con->plugin != NULL) &&
 		    (con->plugin->container_functions != NULL)) {
@@ -863,12 +863,12 @@ static void commit_containers(commit_phase_t phase) {
 static void commit_regions(commit_phase_t phase) {
 
 	int rc = 0;
-	list_element_t iter;
+	list_element_t iter, iter2;
 	storage_object_t * region;
 
 	LOG_PROC_ENTRY();
 
-	LIST_FOR_EACH(&regions_list, iter, region) {
+	LIST_FOR_EACH_SAFE(&regions_list, iter, iter2, region) {
 		if ((region->flags & SOFLAG_DIRTY) &&
 		    (region->plugin != NULL) &&
 		    (region->plugin->functions.plugin != NULL)) {
