@@ -1156,6 +1156,9 @@ int evms_set_info(engine_handle_t  thing_handle,
 
 							if (!(obj->volume->flags & VOLFLAG_NEW)) {
 								/* Put it on the volume_delete_list. */
+								if (obj->volume->flags & VOLFLAG_ACTIVE) {
+									obj->volume->flags |= VOLFLAG_NEEDS_DEACTIVATE;
+								}
 								el = insert_thing(&volume_delete_list,
 										  obj->volume,
 										  INSERT_AFTER,
