@@ -853,7 +853,7 @@ static int read_config(char * * buffer) {
 	if (rc == 0) {
 		config_fd = open(config_file_name, O_RDONLY);
 
-		if (config_fd > 0) {
+		if (config_fd != -1) {
 			/* Close this file for all exec'd processes. */
 			fcntl(config_fd, F_SETFD, FD_CLOEXEC);
 
