@@ -507,7 +507,7 @@ int run_command_v4(void *dmi_in, unsigned long command)
 			}
 		}
 	} else {
-		LOG_WARNING("Device-Mapper control file not open.");
+		LOG_WARNING("Device-Mapper control file not open.\n");
 	}
 
 	LOG_PROC_EXIT_INT(rc);
