@@ -546,7 +546,7 @@ static void generic_deallocate_target(dm_target_t *target)
 
 
 /*************************
- * Linear target routines. 
+ * Linear target routines.
  */
 
 /**
@@ -1211,6 +1211,7 @@ out:
 static int multipath_translate_params_v1(dm_target_t *target)
 {
 	dm_target_multipath_t *mp = target->data.multipath;
+	dm_path_t *current_path = mp->group[0].path;
 	char *params = target->params;
 	int i, j, k, sz, rc;
 
@@ -1236,12 +1237,8 @@ static int multipath_translate_params_v1(dm_target_t *target)
 		params = next_token(params);
 		params = next_token(params);
 
-		mp->group[i].path = engine_alloc(mp->group[i].num_paths *
-						 sizeof(dm_path_t));
-		if (!mp->group[i].path) {
-			rc = ENOMEM;
-			goto out;
-		}
+		mp->group[i].path = current_path;
+		current_path += mp->group[i].num_paths;
 
 		for (j = 0; j < mp->group[i].num_paths; j++) {
 			rc = translate_device(&params,
@@ -1277,6 +1274,7 @@ out:
 static int multipath_translate_params_v2(dm_target_t *target)
 {
 	dm_target_multipath_t *mp = target->data.multipath;
+	dm_path_t *current_path = mp->group[0].path;
 	char *params = target->params;
 	u_int32_t num, i, j, k;
 	int sz, rc;
@@ -1344,12 +1342,8 @@ static int multipath_translate_params_v2(dm_target_t *target)
 		params = next_token(params);
 		params = next_token(params);
 
-		mp->group[i].path = engine_alloc(mp->group[i].num_paths *
-						 sizeof(dm_path_t));
-		if (!mp->group[i].path) {
-			rc = ENOMEM;
-			goto out;
-		}
+		mp->group[i].path = current_path;
+		current_path += mp->group[i].num_paths;
 
 		for (j = 0; j < mp->group[i].num_paths; j++) {
 			rc = translate_device(&params,
@@ -1858,8 +1852,8 @@ out:
  *
  * Generate an ASCII constructor string for a raid target.
  * A raid string has the form:
- *   <log_type> <num_custom_log_params> [<custom_log_params>]* 
- *      <chunk_size> <shared_flag> <num_elements> 
+ *   <log_type> <num_custom_log_params> [<custom_log_params>]*
+ *      <chunk_size> <shared_flag> <num_elements>
  *      [<logmajor>:<logminor> <logstart_lba>] array of log elements
  *      [<major>:<minor> <start_lba>] array of data elements
  *
@@ -1886,7 +1880,7 @@ static int raid_build_params(dm_target_t *target)
 	} else {
 		sz = strlen("core 0");
 	}
-        
+
 	max_len = sz + 20 + (raid->num_elements * 50);
 
 	target->params = get_string(max_len);
@@ -1899,7 +1893,7 @@ static int raid_build_params(dm_target_t *target)
 
 		sz += snprintf(target->params + sz, max_len - sz,
 			       " %u %u %u",
-			       raid->chunk_size, 
+			       raid->chunk_size,
 			       raid->shared_flag,
 			       raid->num_elements);
 
@@ -1935,7 +1929,7 @@ static int raid_build_params(dm_target_t *target)
 /**
  * raid_translate_params
  *
- * Fill in a raid target structure based on an ASCII table string 
+ * Fill in a raid target structure based on an ASCII table string
  * of the form shown above.
  *
  * This is only available using DM version 4.
