@@ -158,6 +158,7 @@ boolean log_usec = FALSE;
 boolean log_pid = FALSE;
 u_char log_buf[LOG_BUF_SIZE];
 pthread_mutex_t log_mutex = PTHREAD_MUTEX_INITIALIZER;
+boolean sync_log = FALSE;
 
 #define ENGINE_LOCK_FILE_DIR	"/var/lock"
 #define ENGINE_LOCK_FILE	ENGINE_LOCK_FILE_DIR "/evms-engine"
@@ -260,6 +261,7 @@ static int start_logging(char * filename) {
 	int i;
 	char * old_archive_log_name;
 	char * new_archive_log_name;
+	int open_flags = O_CREAT | O_TRUNC | O_WRONLY;
 
 	if (log_file_fd == 0) {
 
@@ -279,7 +281,11 @@ static int start_logging(char * filename) {
 		rename(filename, old_archive_log_name);
 		engine_free(old_archive_log_name);
 
-		log_file_fd = open(filename, O_CREAT | O_TRUNC | O_WRONLY, 0664);
+		if (sync_log) {
+			open_flags |= O_SYNC;
+		}
+
+		log_file_fd = open(filename, open_flags, 0664);
 
 		if (log_file_fd < 0) {
 			rc = errno;
@@ -1470,7 +1476,7 @@ static void check_for_2_4_kernel(void)
 			}
 
 		} else {
-			LOG_WARNING("Could not find \"version\" in the version string in /proc/version.");
+			LOG_WARNING("Could not find \"version\" in the version string in /proc/version.\n");
 			LOG_WARNING("Assuming kernel is version 2.4.\n");
 		}
 
@@ -1664,7 +1670,7 @@ int evms_open_engine(char           * node_name,
 	if (geteuid() != 0) {
 		if (callbacks != NULL) {
 			if (callbacks->user_message != NULL) {
-				callbacks->user_message(_("You must have root privilege to open the EVMS Engine."), NULL, NULL);
+				callbacks->user_message(_("You must have root privilege to open the EVMS Engine.\n"), NULL, NULL);
 			}
 		}
 
@@ -1677,6 +1683,7 @@ int evms_open_engine(char           * node_name,
 	debug_level = DEFAULT;
 	log_usec = FALSE;
 	log_pid = FALSE;
+	sync_log = FALSE;
 
 	if ((mode != -1) && (mode & ENGINE_DAEMON)) {
 		log_file_name = DEFAULT_DAEMON_LOG_FILE;
@@ -1702,6 +1709,7 @@ int evms_open_engine(char           * node_name,
 			evms_get_config_string("daemon.log_file", (const char * *) &log_file_name);
 			evms_get_config_bool("daemon.log_usec", &log_usec);
 			evms_get_config_bool("daemon.log_pid", &log_pid);
+			evms_get_config_bool("daemon.sync_log", &sync_log);
 
 		} else {
 			get_config_mode("engine.mode", &open_mode);
@@ -1710,6 +1718,7 @@ int evms_open_engine(char           * node_name,
 			evms_get_config_string("engine.log_file", (const char * *) &log_file_name);
 			evms_get_config_bool("engine.log_usec", &log_usec);
 			evms_get_config_bool("engine.log_pid", &log_pid);
+			evms_get_config_bool("engine.sync_log", &sync_log);
 		}
 	}
 
