@@ -2614,6 +2614,9 @@ int discard_volume(logical_volume_t * vol) {
 			list_element_t el;
 
 			LOG_DEBUG("Volume exists.  Put it on the delete list.\n");
+			if (vol->flags & VOLFLAG_ACTIVE) {
+				vol->flags |= VOLFLAG_NEEDS_DEACTIVATE;
+			}
 			el = insert_thing(&volume_delete_list,
 					  vol,
 					  INSERT_AFTER,
