@@ -2174,6 +2174,9 @@ int evms_convert_to_evms_volume(object_handle_t volume_handle, char * name) {
 			vol->flags &= ~VOLFLAG_UNMKFS;
 
 			/* Delete the old volume. */
+			if (vol->flags & VOLFLAG_ACTIVE) {
+				vol->flags |= VOLFLAG_NEEDS_DEACTIVATE;
+			}
 			el = insert_thing(&volume_delete_list,
 					  vol,
 					  INSERT_AFTER,
@@ -2438,6 +2441,11 @@ int evms_convert_to_compatibility_volume(object_handle_t volume_handle) {
 				 */
 				rc = vol->object->plugin->functions.plugin->add_sectors_to_kill_list(vol->object, vol->object->size - (EVMS_FEATURE_HEADER_SECTORS * 2), EVMS_FEATURE_HEADER_SECTORS * 2);
 
+				/* Deactivate the volume if it is active. */
+				if (vol->flags & VOLFLAG_ACTIVE) {
+					vol->flags |= VOLFLAG_NEEDS_DEACTIVATE;
+				}
+
 			} else {
 				/*
 				 * The old volume was not inserted into the
