@@ -68,6 +68,17 @@ static char pattern[PATH_MAX];
 static dm_device_list_t * dm_devices = NULL;
 static list_anchor_t multipath_children = NULL;
 
+/* Global list for keeping track of open file-handles. On systems with
+ * a large number of disks, we don't want to keep open file-handles to
+ * every disk, or the process may run out of available file-handles.
+ */
+static list_anchor_t file_handles = NULL;
+u_int32_t num_file_handles = 0;
+#define DEFAULT_FILE_HANDLES 64
+#define MAX_FILE_HANDLES 1024
+
+static void close_dev(storage_object_t * disk);
+
 /**
  * round_down
  * @value:	Value (in sectors) to be rounded down.
@@ -214,6 +225,9 @@ static void get_legacy_config()
 	EngFncs->get_config_string_array("legacy_devices.exclude",
 					 &exclude_count, &excludes);
 
+	EngFncs->get_config_uint32("legacy_devices.max_open_disks",
+				   &num_file_handles);
+
 	LOG_EXIT_VOID();
 }
 
@@ -236,11 +250,184 @@ static void get_sysfs_config()
 	EngFncs->get_config_string_array("sysfs_devices.exclude",
 					 &exclude_count, &excludes);
 
+	EngFncs->get_config_uint32("sysfs_devices.max_open_disks",
+				   &num_file_handles);
+
 	LOG_EXIT_VOID();
 }
 
+/**
+ * file_handle_cleanup
+ *
+ * Delete the list of file-handle tracking structures.
+ **/
+static void file_handle_cleanup(void)
+{
+	file_handle_t *handle;
+	list_element_t iter;
+
+	LOG_ENTRY();
+
+	LIST_FOR_EACH(file_handles, iter, handle) {
+		EngFncs->engine_free(handle);
+	}
+
+	EngFncs->destroy_list(file_handles);
+	file_handles = NULL;
+
+	LOG_EXIT_VOID();
+}
+
+/**
+ * file_handle_setup
+ *
+ * Create and initialize MAX_FILE_HANDLES entries on the file_handles list.
+ **/
+static int file_handle_setup(void)
+{
+	file_handle_t *handle;
+	u_int32_t i;
+	int rc = 0;
+
+	LOG_ENTRY();
+
+	/* Make sure the number of entries in the
+	 * file-handles list will be reasonable.
+	 */
+	if (num_file_handles == 0) {
+		num_file_handles = DEFAULT_FILE_HANDLES;
+	} else if (num_file_handles > MAX_FILE_HANDLES) {
+		num_file_handles = MAX_FILE_HANDLES;
+	}
+
+	LOG_DEBUG("Allocating %u entries in the file-handles list.\n",
+		  num_file_handles);
+
+	file_handles = EngFncs->allocate_list();
+	if (!file_handles) {
+		rc = ENOMEM;
+		goto out;
+	}
+
+	for (i = 0; i < num_file_handles; i++) {
+		handle = EngFncs->engine_alloc(sizeof(*handle));
+		if (!handle) {
+			file_handle_cleanup();
+			rc = ENOMEM;
+			break;
+		}
+		handle->elem = EngFncs->insert_thing(file_handles, handle,
+						     INSERT_AFTER, NULL);
+	}
+
+out:
+	LOG_EXIT_INT(rc);
+	return rc;
+}
+
+/**
+ * file_handle_release
+ *
+ * Release this file-handle back to the pool of available handles. Move it
+ * to the start of the list so it will be quicker to find on the next search.
+ **/
+static void file_handle_release(file_handle_t *handle)
+{
+	LOG_ENTRY();
+
+	handle->disk = NULL;
+	EngFncs->remove_element(handle->elem);
+	EngFncs->insert_element(file_handles, handle->elem, INSERT_BEFORE, NULL);
+
+	LOG_EXIT_VOID();
+}
+
+/**
+ * file_handle_make_last
+ *
+ * Move this file-handle to the end of the list so it will be the least likely
+ * to be "stolen".
+ **/
+static void file_handle_make_last(file_handle_t *handle)
+{
+	LOG_ENTRY();
+
+	EngFncs->remove_element(handle->elem);
+	EngFncs->insert_element(file_handles, handle->elem, INSERT_AFTER, NULL);
+
+	LOG_EXIT_VOID();
+}
+
+/**
+ * file_handle_find_free
+ *
+ * Search the file-handles list for an unused entry and assign it to this disk.
+ **/
+static file_handle_t *file_handle_find_free(void)
+{
+	file_handle_t *handle;
+	list_element_t iter;
+
+	LOG_ENTRY();
+
+	LIST_FOR_EACH(file_handles, iter, handle) {
+		if (!handle->disk) {
+			break;
+		}
+	}
+
+	LOG_EXIT_PTR(handle);
+	return handle;
+}
+
+/**
+ * file_handle_steal_first
+ *
+ * "Steal" the first file-handle on the list, forceably close the disk that
+ * currently owns it, and assign it to the new disk.
+ **/
+static file_handle_t *file_handle_steal_first(void)
+{
+	file_handle_t *handle;
+
+	LOG_ENTRY();
+
+	handle = EngFncs->first_thing(file_handles, NULL);
+	if (handle->disk) {
+		LOG_DEBUG("Stealing file-handle from disk %s.\n",
+			  handle->disk->name);
+		close_dev(handle->disk);
+	}
+
+	LOG_EXIT_PTR(handle);
+	return handle;
+}
+
+/**
+ * file_handle_get
+ *
+ * Get a file-handle for this disk. First search the list for an used one. If
+ * we can't find one, simply "steal" the first one on the list.
+ **/
+static file_handle_t *file_handle_get(void)
+{
+	file_handle_t *handle;
+
+	LOG_ENTRY();
+
+	handle = file_handle_find_free();
+	if (!handle) {
+		handle = file_handle_steal_first();
+	}
+
+	LOG_EXIT_PTR(handle);
+	return handle;
+}
+
 static int LD_setup(engine_functions_t * engine_function_table)
 {
+	int rc;
+
 	/* save info we get from the engine */
 	EngFncs = engine_function_table;
 
@@ -252,8 +439,10 @@ static int LD_setup(engine_functions_t * engine_function_table)
 		get_legacy_config();
 	}
 
-	LOG_EXIT_INT(0);
-	return 0;
+	rc = file_handle_setup();
+
+	LOG_EXIT_INT(rc);
+	return rc;
 }
 
 /**
@@ -272,14 +461,23 @@ static int open_dev(storage_object_t * disk)
 	LOG_ENTRY();
 
 	if (ld->fd <= 0) {
+		ld->file_handle = file_handle_get();
+		ld->file_handle->disk = disk;
+
 		ld->fd = EngFncs->open_object(disk, O_RDWR | O_DIRECT | O_SYNC);
 		if (ld->fd < 0) {
 			rc = - ld->fd;
+			file_handle_release(ld->file_handle);
+			ld->file_handle = NULL;
 			LOG_DEBUG("Error opening disk %s: %d: %s\n",
 				  disk->name, rc, strerror(rc));
 		}
 	}
 
+	if (!rc) {
+		file_handle_make_last(ld->file_handle);
+	}
+
 	LOG_EXIT_INT(rc);
 	return rc;
 }
@@ -298,9 +496,9 @@ static void close_dev(storage_object_t * disk)
 
 	if (ld->fd >= 0) {
 		rc = EngFncs->close_object(disk, ld->fd);
-		if (!rc) {
-			ld->fd = -1;
-		}
+		file_handle_release(ld->file_handle);
+		ld->file_handle = NULL;
+		ld->fd = -1;
 	}
 
 	LOG_EXIT_VOID();
@@ -333,6 +531,7 @@ static void LD_cleanup(void)
 	}
 
 	destroy_cache();
+	file_handle_cleanup();
 
 	if (base_directory) {
 		free(base_directory);
@@ -1379,10 +1578,16 @@ static storage_object_t * create_logical_disk(storage_object_t * working_disk)
 	storage_object_t * disk = NULL;
 	local_disk_t * working_ld = working_disk->private_data;
 	local_disk_t * ld;
+	char *name;
 	int rc;
 
 	LOG_ENTRY();
 
+	/* Replace exclaimation marks with slashes in the disk name. */
+	for (name = working_disk->name; *name; name++) {
+		if (*name == '!') *name = '/';
+	}
+
 	rc = EngFncs->allocate_logical_disk(working_disk->name, &disk);
 	if (rc) {
 		LOG_SERIOUS("Error allocating new disk object for disk %s: %d: "
@@ -1421,7 +1626,8 @@ static storage_object_t * create_logical_disk(storage_object_t * working_disk)
 		disk->size :
 		(disk->geometry.heads * disk->geometry.sectors_per_track * 1023);
 
-	ld->fd = working_ld->fd;
+	*ld = *working_ld;
+	ld->file_handle->disk = disk;
 
 	find_disk_type(disk);
 
@@ -1472,9 +1678,9 @@ static int LD_discover(list_anchor_t input_list,
 
 		/* Initialize the working disk object. */
 		memset(&working_disk, 0, sizeof(working_disk));
+		memset(&working_ld, 0, sizeof(working_ld));
 		working_disk.private_data = &working_ld;
 		working_ld.fd = -1;
-		working_ld.flags = 0;
 		strncpy(working_disk.name, full_node_path + base_directory_len,
 			EVMS_NAME_SIZE);
 
