@@ -315,7 +315,7 @@ static int Build_EBR_PartitionTable( LOGICALDISK *ld, Extended_Boot_Record *ebr,
                 }
 
                 if (rc!=0) break;
-        } 
+        }
 
 
         LOG_EXIT_INT(rc);
@@ -328,7 +328,7 @@ static int Build_EBR_PartitionTable( LOGICALDISK *ld, Extended_Boot_Record *ebr,
 /*
  *   Create an MBR for the specified disk.
  */
-static int  Write_MasterBootRecord( LOGICALDISK *ld )
+static int  Write_MasterBootRecord( LOGICALDISK *ld, DISKSEG *parent, boolean backup )
 {
         Master_Boot_Record         *boot_sector = malloc(EVMS_VSECTOR_SIZE);
         struct plugin_functions_s  *DevFncs;
@@ -364,10 +364,14 @@ static int  Write_MasterBootRecord( LOGICALDISK *ld )
                                         LOG_DEBUG("     Committing MBR to disk ...\n");
                                         DisplayPartitionTable( ld, &boot_sector->Partition_Table[0], TRUE);
 
-                                        rc = DevFncs->write( ld, 0, 1, (void *) boot_sector );
+					if (backup) {
+						rc = EngFncs->save_metadata(parent->name, ld->name, 0, 1, boot_sector);
+					} else {
+						rc = DevFncs->write( ld, 0, 1, (void *) boot_sector );
+					}
 
                                         if ( (rc ==0) && ( disk_pdata->flags & DISK_HAS_OS2_DLAT_TABLES )) {
-                                                rc = Write_Dlat_Sector( ld, mbr );
+						rc = Write_Dlat_Sector( ld, mbr, parent, backup );
                                         }
 
                                 }
@@ -393,7 +397,8 @@ static int  Write_MasterBootRecord( LOGICALDISK *ld )
 /*
  *   Create an EBR for the specified disk.
  */
-static int  Write_ExtendedBootRecord_Chain( LOGICALDISK *ld, DISKSEG *mbr )
+static int  Write_ExtendedBootRecord_Chain( LOGICALDISK *ld, DISKSEG *mbr,
+					    DISKSEG *parent, boolean backup)
 {
         Master_Boot_Record         *sector_buffer = calloc(1, ld->geometry.bytes_per_sector );
         struct plugin_functions_s  *DevFncs;
@@ -439,12 +444,16 @@ static int  Write_ExtendedBootRecord_Chain( LOGICALDISK *ld, DISKSEG *mbr )
                                         LOG_DEBUG("     Committing EBR seg %s\n", ebr->name );
                                         DisplayPartitionTable( ld, &sector_buffer->Partition_Table[0], FALSE );
 
-                                        rc = DevFncs->write( ld, ebr->start, 1, (void *) sector_buffer );
+					if (backup) {
+						rc = EngFncs->save_metadata(parent->name, ld->name, ebr->start, 1, sector_buffer);
+					} else {
+						rc = DevFncs->write( ld, ebr->start, 1, (void *) sector_buffer );
+					}
 
                                         if (rc==0) {
 
                                                 if ( disk_pdata->flags & DISK_HAS_OS2_DLAT_TABLES ) {
-                                                        rc = Write_Dlat_Sector( ld, ebr );
+                                                        rc = Write_Dlat_Sector( ld, ebr, parent, backup );
                                                 }
 
                                                 // walk forward in ebr chain
@@ -474,7 +483,8 @@ static int  Write_ExtendedBootRecord_Chain( LOGICALDISK *ld, DISKSEG *mbr )
  *   Create an MBR partition table for the specified disk. The seglist should
  *   contain a list of segments on this disk, ordered by starting LBA.
  */
-static int Commit_Embedded_Partition_Tables( LOGICALDISK *ld, DISK_PRIVATE_DATA *disk_pdata, DISKSEG *mbr )
+static int Commit_Embedded_Partition_Tables( LOGICALDISK *ld, DISK_PRIVATE_DATA *disk_pdata,
+					     DISKSEG *mbr, DISKSEG *parent, boolean backup )
 {
         DISKSEG           *seg;
         SEG_PRIVATE_DATA  *pdata;
@@ -488,24 +498,24 @@ static int Commit_Embedded_Partition_Tables( LOGICALDISK *ld, DISK_PRIVATE_DATA
                 pdata = (SEG_PRIVATE_DATA *)seg->private_data;
 
                 switch ( pdata->sys_id ) {
-                
+
                 case BSD_PARTITION:
                 case NETBSD_PARTITION:
                 case OPENBSD_PARTITION:
-                        rc = do_bsd_partition_commit(ld, seg);
+                        rc = do_bsd_partition_commit(ld, seg, parent, backup);
                         break;
                 case UNIXWARE_PARTITION:
-                        rc = do_unixware_partition_commit(ld, seg);
+                        rc = do_unixware_partition_commit(ld, seg, parent, backup);
                         break;
                 case SOLARIS_X86_PARTITION:
-                        rc = do_solaris_x86_partition_commit(ld, seg);
+                        rc = do_solaris_x86_partition_commit(ld, seg, parent, backup);
                         break;
                 default:
                         rc = 0;
                         break;
                 }
 
-        } 
+        }
 
         LOG_EXIT_INT(rc);
         return rc;
@@ -516,29 +526,30 @@ static int Commit_Embedded_Partition_Tables( LOGICALDISK *ld, DISK_PRIVATE_DATA
  *  Called by SEG_COMMIT() to write out partition tables and dlat tables for
  *  the specified disk.
  */
-static int Commit_MSDOS_Partition_Tables(LOGICALDISK *ld, DISK_PRIVATE_DATA *disk_pdata )
+static int Commit_MSDOS_Partition_Tables(LOGICALDISK *ld, DISK_PRIVATE_DATA *disk_pdata,
+					 DISKSEG *parent, boolean backup )
 {
         int rc;
 
         LOG_ENTRY();
 
-        rc = Write_MasterBootRecord(ld);
+        rc = Write_MasterBootRecord(ld, parent, backup);
         if (rc==0) {
 
-                rc = Write_ExtendedBootRecord_Chain(ld, get_mbr_from_seglist(ld->parent_objects));
+                rc = Write_ExtendedBootRecord_Chain(ld, get_mbr_from_seglist(ld->parent_objects), parent, backup);
                 if (rc) {
-                        MESSAGE("Error, a problem occurred while attempting to commit logical drives on disk %s.\n"
-                                "The segment changes were not committed.\n"
-                                "The return code = %d.\n",
-                                ld->name, rc );
+                        MESSAGE( _("A problem occurred while attempting to commit logical drives on disk %s.\n"
+				   "The segment changes were not committed.\n"
+				   "The return code is %d: %s\n"),
+				 ld->name, rc, EngFncs->strerror(rc) );
                 }
 
         }
         else {
-                MESSAGE("Error, a problem occurred while attempting to commit the master boot record on disk %s.\n"
-                        "The segment changes were not committed.\n"
-                        "The return code = %d.\n",
-                        ld->name, rc );
+                MESSAGE( _("A problem occurred while attempting to commit the master boot record on disk %s.\n"
+			   "The segment changes were not committed.\n"
+			   "The return code is %d: %s.\n"),
+			 ld->name, rc, EngFncs->strerror(rc) );
         }
 
         LOG_EXIT_INT(rc);
@@ -550,7 +561,7 @@ static int Commit_MSDOS_Partition_Tables(LOGICALDISK *ld, DISK_PRIVATE_DATA *dis
  *  Called by SEG_COMMIT() to write out partition tables and dlat tables for
  *  the specified disk.
  */
-int  Commit_Disk_Partition_Tables(LOGICALDISK *ld)
+int  Commit_Disk_Partition_Tables(LOGICALDISK *ld, DISKSEG *parent, boolean backup)
 {
         int rc=EINVAL;
         DISK_PRIVATE_DATA *disk_pdata = get_disk_private_data(ld);
@@ -562,14 +573,14 @@ int  Commit_Disk_Partition_Tables(LOGICALDISK *ld)
 
                 if ( (disk_pdata->flags & DISK_HAS_FORCED_LBA_ADDRESSING) == 0 ) {
 
-                        rc = Commit_MSDOS_Partition_Tables(ld, disk_pdata);
+                        rc = Commit_MSDOS_Partition_Tables(ld, disk_pdata, parent, backup);
                         if (!rc) {
-                                rc = Commit_Embedded_Partition_Tables(ld, disk_pdata, mbr);
+                                rc = Commit_Embedded_Partition_Tables(ld, disk_pdata, mbr, parent, backup);
                                 if (rc) {
-                                        MESSAGE("Error, a problem occurred while attempting to commit an embedded partition table on disk %s.\n"
-                                                "The segment changes were not committed.\n"
-                                                "The return code = %d.\n",
-                                                ld->name, rc );
+                                        MESSAGE( _("A problem occurred while attempting to commit an embedded partition table on disk %s.\n"
+						   "The segment changes were not committed.\n"
+						   "The return code is %d: %s.\n"),
+						 ld->name, rc, EngFncs->strerror(rc) );
                                 }
                         }
 
