@@ -285,15 +285,15 @@ static int fs_expand( logical_volume_t * volume,
 	if ((sb->s_lastcheck < sb->s_mtime) ||
 	    (sb->s_state & EXT2_ERROR_FS) ||
 	    ((sb->s_state & EXT2_VALID_FS) == 0)) {
-		MESSAGE("Running fsck before expanding volume");
+		MESSAGE(_("Running fsck before expanding volume."));
 		rc = fsim_fsck(volume, NULL, &status );
 		if (rc) {
-			MESSAGE("Attempt to execute fsck failed (%d)", rc);
-			MESSAGE("Aborting volume expand");
+			MESSAGE(_("Attempt to execute fsck failed (%d).  "
+				  "Aborting volume expand,"), rc);
 			goto errout;
 		}
 		if (status >= 4) {
-			MESSAGE("Aborting volume expand");
+			MESSAGE(_("Aborting volume expand"));
 			rc = status;
 			goto errout;
 		}
@@ -325,7 +325,7 @@ static int fs_expand( logical_volume_t * volume,
 	}
 
 	argv[0] = "resize2fs";
-	SET_STRING(argv[1], EVMS_GET_DEVNAME(volume));
+	argv[1] = EngFncs->engine_strdup(EVMS_GET_DEVNAME(volume));
 	argv[2] = NULL;
 
 	pidf = EngFncs->fork_and_execvp(volume, argv, fds1, fds2, fds2);
@@ -342,7 +342,7 @@ static int fs_expand( logical_volume_t * volume,
 			bytes_read = read(fds2[0],buffer,MAX_USER_MESSAGE_LEN);
 			if (bytes_read > 0) {
 				if (!banner)
-					MESSAGE("expand output:");
+					MESSAGE(_("Expand output:"));
 				banner = 1;
 				MESSAGE("%s", buffer);
 				memset(buffer,0,bytes_read); /* clear out message  */
@@ -353,7 +353,7 @@ static int fs_expand( logical_volume_t * volume,
 		bytes_read = read(fds2[0],buffer,MAX_USER_MESSAGE_LEN);
 		if (bytes_read > 0) {
 			if (!banner)
-				MESSAGE("expand output:");
+				MESSAGE(_("Expand output:"));
 			MESSAGE("%s",buffer);
 		}
 		if (WIFEXITED(status)) {
@@ -440,15 +440,15 @@ static int fs_shrink( logical_volume_t * volume,
 	if ((sb->s_lastcheck < sb->s_mtime) ||
 	    (sb->s_state & EXT2_ERROR_FS) ||
 	    ((sb->s_state & EXT2_VALID_FS) == 0)) {
-		MESSAGE("Running fsck before shrinking volume");
+		MESSAGE(_("Running fsck before shrinking volume."));
 		rc = fsim_fsck(volume, NULL, &status );
 		if (rc) {
-			MESSAGE("Attempt to execute fsck failed (%d)", rc);
-			MESSAGE("Aborting volume shrink");
+			MESSAGE(_("Attempt to execute fsck failed (%d).  "
+				  "Aborting volume shrink."), rc);
 			goto errout;
 		}
 		if (status >= 4) {
-			MESSAGE("Aborting volume shrink");
+			MESSAGE(_("Aborting volume shrink"));
 			rc = status;
 		}
 	}
@@ -473,7 +473,7 @@ static int fs_shrink( logical_volume_t * volume,
 	}
 
 	argv[0] = "resize2fs";
-	SET_STRING(argv[1], EVMS_GET_DEVNAME(volume));
+	argv[1] = EngFncs->engine_strdup(EVMS_GET_DEVNAME(volume));
 	sprintf(size_buf,"%"PRIu64, requested_size);
 	argv[2] = size_buf;
 	argv[3] = NULL;
@@ -493,7 +493,7 @@ static int fs_shrink( logical_volume_t * volume,
 			bytes_read = read(fds2[0],buffer,MAX_USER_MESSAGE_LEN);
 			if (bytes_read > 0) {
 				if (!banner)
-					MESSAGE("Shrink output:");
+					MESSAGE(_("Shrink output:"));
 				banner = 1;
 				MESSAGE("%s", buffer);
 				memset(buffer,0,bytes_read); /* clear out message  */
@@ -504,7 +504,7 @@ static int fs_shrink( logical_volume_t * volume,
 		bytes_read = read(fds2[0],buffer,MAX_USER_MESSAGE_LEN);
 		if (bytes_read > 0) {
 			if (!banner)
-				MESSAGE("Shrink output:");
+				MESSAGE(_("Shrink output:"));
 			MESSAGE("%s",buffer);
 		}
 		if (WIFEXITED(status)) {
@@ -596,12 +596,13 @@ static int fs_fsck(logical_volume_t * volume, option_array_t * options )
 	 * them.
 	 */
 	if (EVMS_IS_MOUNTED(volume) && (status & FSCK_ERRORS_UNCORRECTED)) {
-		MESSAGE( "%s is mounted.", EVMS_GET_DEVNAME(volume) );
-		MESSAGE( "e2fsck checked the volume READ ONLY and found, but did not fix, errors." );
-		MESSAGE( "Unmount %s and run e2fsck again to repair the file system.", EVMS_GET_DEVNAME(volume) );
+		MESSAGE( _("%s is mounted.  "
+			   "e2fsck checked the volume READ ONLY and found, but did not fix, errors.  "
+			   "Unmount %s and run e2fsck again to repair the file system."),
+			 EVMS_GET_DEVNAME(volume), EVMS_GET_DEVNAME(volume) );
 	}
 	if (status > 4) {
-		MESSAGE( "e2fsck exited with status code %d.", status);
+		MESSAGE( _("e2fsck exited with status code %d."), status);
 	}
 
 errout:
@@ -713,9 +714,9 @@ static int fs_init_task( task_context_t * context )
 
 		/* check for bad blocks option */
 		opt = &context->option_descriptors->option[MKFS_CHECKBB_INDEX];
-		SET_STRING(opt->name, "badblocks" );
-		SET_STRING(opt->title, "Check For Bad Blocks" );
-		SET_STRING(opt->tip, "Check the volume for bad blocks before building the file system." );
+		opt->name = EngFncs->engine_strdup("badblocks" );
+		opt->title = EngFncs->engine_strdup(_("Check For Bad Blocks"));
+		opt->tip = EngFncs->engine_strdup(_("Check the volume for bad blocks before building the file system."));
 		opt->help = NULL;
 		opt->type = EVMS_Type_Boolean;
 		opt->unit = EVMS_Unit_None;
@@ -728,9 +729,9 @@ static int fs_init_task( task_context_t * context )
 
 		/* check for r/w bad blocks option */
 		opt = &context->option_descriptors->option[MKFS_CHECKRW_INDEX];
-		SET_STRING(opt->name, "badblocks_rw" );
-		SET_STRING(opt->title, "RW Check For Bad Blocks" );
-		SET_STRING(opt->tip, "Do a read/write check for bad blocks before building the file system." );
+		opt->name = EngFncs->engine_strdup("badblocks_rw" );
+		opt->title = EngFncs->engine_strdup(_("Read/Write Check For Bad Blocks"));
+		opt->tip = EngFncs->engine_strdup(_("Do a read/write check for bad blocks before building the file system."));
 		opt->help = NULL;
 		opt->type = EVMS_Type_Boolean;
 		opt->unit = EVMS_Unit_None;
@@ -743,9 +744,9 @@ static int fs_init_task( task_context_t * context )
 
 		/* Set Volume Label option */
 		opt = &context->option_descriptors->option[MKFS_SETVOL_INDEX];
-		SET_STRING(opt->name, "vollabel" );
-		SET_STRING(opt->title, "Volume Label" );
-		SET_STRING(opt->tip, "Set the volume label for the file system." );
+		opt->name = EngFncs->engine_strdup("vollabel" );
+		opt->title = EngFncs->engine_strdup(_("Volume Label"));
+		opt->tip = EngFncs->engine_strdup(_("Set the volume label for the file system."));
 		opt->help = NULL;
 		opt->type = EVMS_Type_String;
 		opt->unit = EVMS_Unit_None;
@@ -765,9 +766,9 @@ static int fs_init_task( task_context_t * context )
 
 		/* create ext3 journal option */
 		opt = &context->option_descriptors->option[MKFS_JOURNAL_INDEX];
-		SET_STRING(opt->name, "journal" );
-		SET_STRING(opt->title, "Create Ext3 Journal" );
-		SET_STRING(opt->tip, "Create a journal for use with the ext3 file system." );
+		opt->name = EngFncs->engine_strdup("journal" );
+		opt->title = EngFncs->engine_strdup(_("Create Ext3 Journal"));
+		opt->tip = EngFncs->engine_strdup(_("Create a journal for use with the ext3 file system."));
 		opt->help = NULL;
 		opt->type = EVMS_Type_Boolean;
 		opt->unit = EVMS_Unit_None;
@@ -788,9 +789,9 @@ static int fs_init_task( task_context_t * context )
 
 		/* force check option */
 		opt = &context->option_descriptors->option[FSCK_FORCE_INDEX];
-		SET_STRING(opt->name, "force" );
-		SET_STRING(opt->title, "Force Check" );
-		SET_STRING(opt->tip, "Force complete file system check." );
+		opt->name = EngFncs->engine_strdup("force" );
+		opt->title = EngFncs->engine_strdup(_("Force Check"));
+		opt->tip = EngFncs->engine_strdup(_("Force complete file system check."));
 		opt->help = NULL;
 		opt->type = EVMS_Type_Boolean;
 		opt->unit = EVMS_Unit_None;
@@ -803,9 +804,9 @@ static int fs_init_task( task_context_t * context )
 
 		/* read-only check option */
 		opt = &context->option_descriptors->option[FSCK_READONLY_INDEX];
-		SET_STRING(opt->name, "readonly" );
-		SET_STRING(opt->title, "Check Read-Only" );
-		SET_STRING(opt->tip, "Check the file system READ ONLY.  Report but do not correct errors." );
+		opt->name = EngFncs->engine_strdup("readonly" );
+		opt->title = EngFncs->engine_strdup(_("Check Read-Only"));
+		opt->tip = EngFncs->engine_strdup(_("Check the file system READ ONLY.  Report but do not correct errors."));
 		opt->help = NULL;
 		opt->type = EVMS_Type_Boolean;
 		opt->unit = EVMS_Unit_None;
@@ -823,9 +824,9 @@ static int fs_init_task( task_context_t * context )
 
 		/* check for bad blocks option */
 		opt = &context->option_descriptors->option[FSCK_CHECKBB_INDEX];
-		SET_STRING(opt->name, "badblocks" );
-		SET_STRING(opt->title, "Check For Bad Blocks" );
-		SET_STRING(opt->tip, "Check for bad blocks and mark them as busy." );
+		opt->name = EngFncs->engine_strdup("badblocks" );
+		opt->title = EngFncs->engine_strdup(_("Check For Bad Blocks"));
+		opt->tip = EngFncs->engine_strdup(_("Check for bad blocks and mark them as busy."));
 		opt->help = NULL;
 #ifdef ABI_EVMS_1_0
 		opt->size = 0;
@@ -842,9 +843,9 @@ static int fs_init_task( task_context_t * context )
 
 		/* check for r/w bad blocks option */
 		opt = &context->option_descriptors->option[FSCK_CHECKRW_INDEX];
-		SET_STRING(opt->name, "badblocks_rw" );
-		SET_STRING(opt->title, "RW Check For Bad Blocks" );
-		SET_STRING(opt->tip, "Do a read/write check for bad blocks and mark them as busy." );
+		opt->name = EngFncs->engine_strdup("badblocks_rw" );
+		opt->title = EngFncs->engine_strdup(_("RW Check For Bad Blocks"));
+		opt->tip = EngFncs->engine_strdup(_("Do a read/write check for bad blocks and mark them as busy."));
 		opt->help = NULL;
 		opt->type = EVMS_Type_Boolean;
 		opt->unit = EVMS_Unit_None;
@@ -861,9 +862,9 @@ static int fs_init_task( task_context_t * context )
 
 		/* timing option */
 		opt = &context->option_descriptors->option[FSCK_TIMING_INDEX];
-		SET_STRING(opt->name, "timing" );
-		SET_STRING(opt->title, "Timing Statistics" );
-		SET_STRING(opt->tip, "Print timing statistics." );
+		opt->name = EngFncs->engine_strdup("timing" );
+		opt->title = EngFncs->engine_strdup(_("Timing Statistics"));
+		opt->tip = EngFncs->engine_strdup(_("Print timing statistics."));
 		opt->help = NULL;
 		opt->type = EVMS_Type_Boolean;
 		opt->unit = EVMS_Unit_None;
@@ -972,7 +973,7 @@ static int fs_set_option( task_context_t * context,
 		case FSCK_CHECKBB_INDEX:
 		case FSCK_CHECKRW_INDEX:
 			if (EVMS_IS_MOUNTED(context->volume) && value->b) {
-				MESSAGE("Can't check for bad blocks when the volume is mounted.");
+				MESSAGE(_("Can't check for bad blocks when the volume is mounted."));
 				context->option_descriptors->option[index].value.b = FALSE;
 				*effect |= EVMS_Effect_Reload_Options;
 				break;
@@ -1052,9 +1053,12 @@ static int fs_set_volumes( task_context_t * context,
 					/*****************************************************
 					 *  FUTURE - move this volume to unacceptable list   *
 					 *****************************************************/
+					char number_buffer[64];
 
-					MESSAGE( "The size of volume %s is %"PRIu64" bytes.", EVMS_GET_DEVNAME(vol), vol->vol_size * PBSIZE );
-					MESSAGE( "mke2fs requires a minimum of %u bytes to build the ext2/3 file system.", MINEXT2 );
+					sprintf(number_buffer, "%"PRIu64, vol->vol_size * PBSIZE);
+					MESSAGE( _("The size of volume %s is %s bytes.  "
+						   "mke2fs requires a minimum of %u bytes to build the ext2/3 file system."),
+						 EVMS_GET_DEVNAME(vol), number_buffer, MINEXT2 );
 					rc = EPERM;
 				}
 			}
@@ -1129,35 +1133,35 @@ static int fs_get_volume_info( logical_volume_t        * volume,
 
 	Info->count = 5;
 
-	SET_STRING( Info->info[0].name, "Version" );
-	SET_STRING( Info->info[0].title, "Ext2 Revision Number" );
-	SET_STRING( Info->info[0].desc, "Ext2 Revision Number.");
+	Info->info[0].name = EngFncs->engine_strdup( "Version" );
+	Info->info[0].title = EngFncs->engine_strdup( _("Ext2 Revision Number") );
+	Info->info[0].desc = EngFncs->engine_strdup( _("Ext2 Revision Number.") );
 	Info->info[0].type               = EVMS_Type_Unsigned_Int32;
 	Info->info[0].unit               = EVMS_Unit_None;
 	Info->info[0].value.ui32         = sb_ptr->s_rev_level;
 	Info->info[0].collection_type    = EVMS_Collection_None;
 	memset( &Info->info[0].group, 0, sizeof(group_info_t));
 
-	SET_STRING( Info->info[1].name, "State" );
-	SET_STRING( Info->info[1].title, "Ext2 State" );
-	SET_STRING( Info->info[1].desc, "The state of Ext2.");
+	Info->info[1].name = EngFncs->engine_strdup( "State" );
+	Info->info[1].title = EngFncs->engine_strdup( _("Ext2 State") );
+	Info->info[1].desc = EngFncs->engine_strdup( _("The state of Ext2.") );
 	Info->info[1].type               = EVMS_Type_String;
 	Info->info[1].unit               = EVMS_Unit_None;
 	if (sb_ptr->s_feature_incompat & EXT3_FEATURE_INCOMPAT_RECOVER) {
-		SET_STRING(Info->info[1].value.s, "Needs journal replay");
+		Info->info[1].value.s = EngFncs->engine_strdup(_("Needs journal replay"));
 	} else if (sb_ptr->s_state & EXT2_ERROR_FS) {
-		SET_STRING(Info->info[1].value.s, "Had errors");
+		Info->info[1].value.s = EngFncs->engine_strdup(_("Had errors"));
 	} else if (sb_ptr->s_state & EXT2_VALID_FS) {
-		SET_STRING(Info->info[1].value.s, "Clean");
+		Info->info[1].value.s = EngFncs->engine_strdup(_("Clean"));
 	} else {
-		SET_STRING(Info->info[1].value.s, "Dirty");
+		Info->info[1].value.s = EngFncs->engine_strdup(_("Dirty"));
 	}
 	Info->info[1].collection_type    = EVMS_Collection_None;
 	memset( &Info->info[1].group, 0, sizeof(group_info_t));
 
-	SET_STRING( Info->info[2].name, "VolLabel" );
-	SET_STRING( Info->info[2].title, "Volume Label" );
-	SET_STRING( Info->info[2].desc, "File system volume label.");
+	Info->info[2].name = EngFncs->engine_strdup( "VolLabel" );
+	Info->info[2].title = EngFncs->engine_strdup( _("Volume Label") );
+	Info->info[2].desc = EngFncs->engine_strdup( _("File system volume label.") );
 	Info->info[2].type               = EVMS_Type_String;
 	Info->info[2].unit               = EVMS_Unit_None;
 
@@ -1169,9 +1173,9 @@ static int fs_get_volume_info( logical_volume_t        * volume,
 	Info->info[2].collection_type    = EVMS_Collection_None;
 	memset( &Info->info[2].group, 0, sizeof(group_info_t));
 
-	SET_STRING( Info->info[3].name, "Size" );
-	SET_STRING( Info->info[3].title, "File System Size" );
-	SET_STRING( Info->info[3].desc, "Size of the file system.");
+	Info->info[3].name = EngFncs->engine_strdup( "Size" );
+	Info->info[3].title = EngFncs->engine_strdup( _("File System Size") );
+	Info->info[3].desc = EngFncs->engine_strdup( _("Size of the file system.") );
 	Info->info[3].type               = EVMS_Type_Unsigned_Int64;
 	Info->info[3].unit               = EVMS_Unit_Sectors;
 	Info->info[3].value.ui64         = sb_ptr->s_blocks_count <<
@@ -1179,9 +1183,9 @@ static int fs_get_volume_info( logical_volume_t        * volume,
 	Info->info[3].collection_type    = EVMS_Collection_None;
 	memset( &Info->info[3].group, 0, sizeof(group_info_t));
 
-	SET_STRING( Info->info[4].name, "FreeSpace" );
-	SET_STRING( Info->info[4].title, "Free File System Space" );
-	SET_STRING( Info->info[4].desc, "Amount of unused space in the file system.");
+	Info->info[4].name = EngFncs->engine_strdup( "FreeSpace" );
+	Info->info[4].title = EngFncs->engine_strdup( _("Free File System Space") );
+	Info->info[4].desc = EngFncs->engine_strdup( _("Amount of unused space in the file system.") );
 	Info->info[4].type               = EVMS_Type_Unsigned_Int64;
 	Info->info[4].unit               = EVMS_Unit_Sectors;
 	Info->info[4].value.ui64         = sb_ptr->s_free_blocks_count <<
@@ -1250,85 +1254,87 @@ static int fs_get_plugin_info( char * descriptor_name, extended_info_array_t * *
 #endif
 
 				iptr = &Info->info[Info->count++];
-				SET_STRING( iptr->name, "Short Name" );
-				SET_STRING( iptr->title, "Short Name" );
-				SET_STRING( iptr->desc, "A short name given to this plugin.");
+				iptr->name = EngFncs->engine_strdup( "Short Name" );
+				iptr->title = EngFncs->engine_strdup( _("Short Name") );
+				iptr->desc = EngFncs->engine_strdup( _("A short name given to this plug-in") );
 				iptr->type               = EVMS_Type_String;
 				iptr->unit               = EVMS_Unit_None;
-				SET_STRING( iptr->value.s, my_plugin_record->short_name );
+				iptr->value.s = EngFncs->engine_strdup( my_plugin_record->short_name );
 				iptr->collection_type    = EVMS_Collection_None;
 				memset( &iptr->group, 0, sizeof(group_info_t));
 
 				iptr = &Info->info[Info->count++];
-				SET_STRING( iptr->name, "Long Name" );
-				SET_STRING( iptr->title, "Long Name" );
-				SET_STRING( iptr->desc, "A long name given to this plugin.");
+				iptr->name = EngFncs->engine_strdup( "Long Name" );
+				iptr->title = EngFncs->engine_strdup( _("Long Name") );
+				iptr->desc = EngFncs->engine_strdup( _("A longer, more descriptive name for this plug-in") );
 				iptr->type               = EVMS_Type_String;
 				iptr->unit               = EVMS_Unit_None;
-				SET_STRING( iptr->value.s, my_plugin_record->long_name );
+				iptr->value.s = EngFncs->engine_strdup( my_plugin_record->long_name );
 				iptr->collection_type    = EVMS_Collection_None;
 				memset( &iptr->group, 0, sizeof(group_info_t));
 
 				iptr = &Info->info[Info->count++];
-				SET_STRING( iptr->name, "Type" );
-				SET_STRING( iptr->title, "Plugin Type" );
-				SET_STRING( iptr->desc, "There are various types of plugins; each responsible for some kind of storage object.");
+				iptr->name = EngFncs->engine_strdup( "Type" );
+				iptr->title = EngFncs->engine_strdup( _("Plug-in Type") );
+				iptr->desc = EngFncs->engine_strdup( _("There are various types of plug-ins, each responsible for some kind of storage object or logical volume.") );
 				iptr->type               = EVMS_Type_String;
 				iptr->unit               = EVMS_Unit_None;
-				SET_STRING( iptr->value.s, "File System Interface Module" );
+				iptr->value.s = EngFncs->engine_strdup( _("File System Interface Module") );
 				iptr->collection_type    = EVMS_Collection_None;
 				memset( &iptr->group, 0, sizeof(group_info_t));
 
 				iptr = &Info->info[Info->count++];
-				SET_STRING( iptr->name, "Version" );
-				SET_STRING( iptr->title, "Plugin Version" );
-				SET_STRING( iptr->desc, "This is the version number of the plugin.");
+				iptr->name = EngFncs->engine_strdup( "Version" );
+				iptr->title = EngFncs->engine_strdup( _("Plug-in Version") );
+				iptr->desc = EngFncs->engine_strdup( _("This is the version number of the plug-in.") );
 				iptr->type               = EVMS_Type_String;
 				iptr->unit               = EVMS_Unit_None;
-				SET_STRING( iptr->value.s, version_string );
+				iptr->value.s = EngFncs->engine_strdup( version_string );
 				iptr->collection_type    = EVMS_Collection_None;
 				memset( &iptr->group, 0, sizeof(group_info_t));
 
 #ifdef ABI_EVMS_1_0
 				iptr = &Info->info[Info->count++];
-				SET_STRING( iptr->name, "Required Version" );
-				SET_STRING( iptr->title, "Required Engine Version" );
-				SET_STRING( iptr->desc, "This is the version of the engine that the plugin requires. It will not run on older versions of the Engine.");
+				iptr->name = EngFncs->engine_strdup( "Required Version" );
+				iptr->title = EngFncs->engine_strdup( _("Required Engine Version") );
+				iptr->desc = EngFncs->engine_strdup( _("This is the version of the engine that the plugin requires.  "
+								       "It will not run on older versions of the Engine.") );
 				iptr->type               = EVMS_Type_String;
 				iptr->unit               = EVMS_Unit_None;
-				SET_STRING( iptr->value.s, required_version_string );
+				iptr->value.s = EngFncs->engine_strdup( required_version_string );
 				iptr->collection_type    = EVMS_Collection_None;
 				memset( &iptr->group, 0, sizeof(group_info_t));
 #else
 				iptr = &Info->info[Info->count++];
-				SET_STRING( iptr->name, "Required Engine Services Version" );
-				SET_STRING( iptr->title, "Required Engine Services Version" );
-				SET_STRING( iptr->desc, "This is the version of the Engine services that this plug-in requires. It will not run on older versions of the Engine services.");
+				iptr->name = EngFncs->engine_strdup( "Required Engine Services Version" );
+				iptr->title = EngFncs->engine_strdup( _("Required Engine Services Version") );
+				iptr->desc = EngFncs->engine_strdup( _("This is the version of the Engine services that this plug-in requires.  "
+								       "It will not run on older versions of the Engine services.") );
 				iptr->type               = EVMS_Type_String;
 				iptr->unit               = EVMS_Unit_None;
-				SET_STRING( iptr->value.s, required_engine_api_version_string );
+				iptr->value.s = EngFncs->engine_strdup( required_engine_api_version_string );
 				iptr->collection_type    = EVMS_Collection_None;
 				memset( &iptr->group, 0, sizeof(group_info_t));
 
 				iptr = &Info->info[Info->count++];
-				SET_STRING( iptr->name, "Required Engine FSIM API Version" );
-				SET_STRING( iptr->title, "Required Engine FSIM API Version" );
-				SET_STRING( iptr->desc, "This is the version of the Engine FSIM API that this plug-in requires. It will not run on older versions of the Engine FSIM API.");
+				iptr->name = EngFncs->engine_strdup( "Required Engine FSIM API Version" );
+				iptr->title = EngFncs->engine_strdup( _("Required Engine FSIM API Version") );
+				iptr->desc = EngFncs->engine_strdup( _("This is the version of the Engine FSIM API that this plug-in requires. It will not run on older versions of the Engine FSIM API.") );
 				iptr->type               = EVMS_Type_String;
 				iptr->unit               = EVMS_Unit_None;
-				SET_STRING( iptr->value.s, required_fsim_api_version_string );
+				iptr->value.s = EngFncs->engine_strdup( required_fsim_api_version_string );
 				iptr->collection_type    = EVMS_Collection_None;
 				memset( &iptr->group, 0, sizeof(group_info_t));
 #endif
 
 #if defined(PACKAGE) && defined(VERSION)
 				iptr = &Info->info[Info->count++];
-				SET_STRING( iptr->name, "E2fsprogs Version" );
-				SET_STRING( iptr->title, "E2fsprogs Version" );
-				SET_STRING( iptr->desc, "This is the version of the e2fsprogs that this plugin was shipped with.");
+				iptr->name = EngFncs->engine_strdup( "E2fsprogs Version" );
+				iptr->title = EngFncs->engine_strdup( _("E2fsprogs Version") );
+				iptr->desc = EngFncs->engine_strdup( _("This is the version of the e2fsprogs that this plugin was shipped with.") );
 				iptr->type               = EVMS_Type_String;
 				iptr->unit               = EVMS_Unit_None;
-				SET_STRING( iptr->value.s, VERSION );
+				iptr->value.s = EngFncs->engine_strdup( VERSION );
 				iptr->collection_type    = EVMS_Collection_None;
 				memset( &iptr->group, 0, sizeof(group_info_t));
 #endif
@@ -1368,7 +1374,7 @@ static int fs_can_expand_by(logical_volume_t * volume,
 			  &volume->min_fs_size,
 			  &volume->max_fs_size,
 			  &volume->max_vol_size);
-	if (volume->fs_size + *delta > volume->max_fs_size) {
+	if (*delta > volume->max_fs_size - volume->fs_size) {
 		*delta = volume->max_fs_size - volume->fs_size;
 	}
 errout:
@@ -1394,10 +1400,10 @@ static int fs_can_shrink_by(logical_volume_t * volume,
 			  &volume->min_fs_size,
 			  &volume->max_fs_size,
 			  &volume->max_vol_size);
-	if (volume->fs_size - *delta < volume->min_fs_size) {
+	if (*delta > volume->fs_size - volume->min_fs_size) {
 		*delta = volume->fs_size - volume->min_fs_size;
 	}
-	if (volume->min_fs_size >= volume->vol_size) {
+	if (volume->min_fs_size >= volume->fs_size) {
 		rc = ENOSPC;
 	}
 errout:
@@ -1447,13 +1453,13 @@ plugin_record_t ext2_plugin_record = {
 	},
 #else
 	.required_engine_api_version = {
-		.major		= 13,
+		.major		= 15,
 		.minor		= 0,
 		.patchlevel	= 0
 	},
 	.required_plugin_api_version = {
 		.fsim = {
-			.major		= 10,
+			.major		= 11,
 			.minor		= 0,
 			.patchlevel	= 0
 		}
