@@ -19,6 +19,7 @@
  * 	Module: ece.c
  */
 #include <ece.h>
+#include <sys/poll.h>
 #include "eceinternal.h"
 
 #if (HA_MAJOR < 1) || ((HA_MAJOR == 1) && (HA_MINOR < 2))
@@ -2334,70 +2335,68 @@ ece_get_plugin_info(char  * info_name,
 
     if (!info_name) {
         if (!(info = ENGINE_ALLOC(sizeof(extended_info_array_t) +
-			sizeof(extended_info_t)*5))) {
+			sizeof(extended_info_t)*6))) {
             LOG_CRITICAL("Error allocating memory for info array\n");
             LOG_EXIT_INT(ENOMEM);
             return ENOMEM;
         }
 
-        SET_STRING(info->info[i].name, "ShortName");
-        SET_STRING(info->info[i].title, "Short Name");
-        SET_STRING(info->info[i].desc, "A short name given to this plugin");
+        info->info[i].name = EngFncs->engine_strdup("ShortName");
+        info->info[i].title = EngFncs->engine_strdup(_("Short Name"));
+        info->info[i].desc = EngFncs->engine_strdup(_("A short name given to this plug-in"));
         info->info[i].type = EVMS_Type_String;
-        SET_STRING(info->info[i].value.s, ece_plugin_record.short_name);
+        info->info[i].value.s = EngFncs->engine_strdup(ece_plugin_record.short_name);
         i++;
 
-        SET_STRING(info->info[i].name, "LongName");
-        SET_STRING(info->info[i].title, "Long Name");
-        SET_STRING(info->info[i].desc, "A long name given to this plugin");
+        info->info[i].name = EngFncs->engine_strdup("LongName");
+        info->info[i].title = EngFncs->engine_strdup(_("Long Name"));
+        info->info[i].desc = EngFncs->engine_strdup(_("A longer, more descriptive name for this plug-in"));
         info->info[i].type = EVMS_Type_String;
-        SET_STRING(info->info[i].value.s, ece_plugin_record.long_name);
+        info->info[i].value.s = EngFncs->engine_strdup(ece_plugin_record.long_name);
         i++;
 
-        SET_STRING(info->info[i].name, "Type");
-        SET_STRING(info->info[i].title, "Plugin Type");
-        SET_STRING(info->info[i].desc, "There are various "
-		"types of plugins; each responsible for "
-		"some kind of storage object.");
+        info->info[i].name = EngFncs->engine_strdup("Type");
+        info->info[i].title = EngFncs->engine_strdup(_("Plug-in Type"));
+        info->info[i].desc =
+		EngFncs->engine_strdup(_("There are various types of plug-ins, each responsible for some kind of storage object or logical volume."));
         info->info[i].type = EVMS_Type_String;
-        SET_STRING(info->info[i].value.s, "Cluster Manager");
+        info->info[i].value.s = EngFncs->engine_strdup(_("Cluster Manager"));
         i++;
 
-        SET_STRING(info->info[i].name, "Version");
-        SET_STRING(info->info[i].title, "Plugin Version");
-        SET_STRING(info->info[i].desc,
-			"This is the version number of the plugin.");
+        info->info[i].name = EngFncs->engine_strdup("Version");
+        info->info[i].title = EngFncs->engine_strdup(_("Plug-in Version"));
+        info->info[i].desc =
+		EngFncs->engine_strdup(_("This is the version number of the plug-in."));
         info->info[i].type = EVMS_Type_String;
         snprintf(buffer, 50, "%d.%d.%d", MAJOR_VERSION,
 			MINOR_VERSION, PATCH_LEVEL);
-        SET_STRING(info->info[i].value.s, buffer);
+        info->info[i].value.s = EngFncs->engine_strdup(buffer);
         i++;
 
-        SET_STRING(info->info[i].name, "Required_Engine_Version");
-        SET_STRING(info->info[i].title, "Required Engine Services Version");
-        SET_STRING(info->info[i].desc, "This is the version of the Engine "
-			"services that this plug-in requires.  It will not "
-			"run on older versions of the Engine services.");
+        info->info[i].name = EngFncs->engine_strdup("Required_Engine_Version");
+        info->info[i].title = EngFncs->engine_strdup(_("Required Engine Services Version"));
+        info->info[i].desc =
+		EngFncs->engine_strdup(_("This is the version of the Engine services that this plug-in requires.  "
+					 "It will not run on older versions of the Engine services."));
         info->info[i].type = EVMS_Type_String;
         snprintf(buffer, 50, "%d.%d.%d",
 		ece_plugin_record.required_engine_api_version.major,
 		ece_plugin_record.required_engine_api_version.minor,
 		ece_plugin_record.required_engine_api_version.patchlevel);
-        SET_STRING(info->info[i].value.s, buffer);
+        info->info[i].value.s = EngFncs->engine_strdup(buffer);
         i++;
 
-        SET_STRING(info->info[i].name, "Required_Cluster_Version");
-        SET_STRING(info->info[i].title, "Required Cluster API Version");
-        SET_STRING(info->info[i].desc, "This is the version of the "
-			"Engine's cluster plug-in API that this plug-in "
-			"requires.  It will not run on older versions of "
-			"the Engine's cluster plug-in API.");
+        info->info[i].name = EngFncs->engine_strdup("Required_Cluster_Version");
+        info->info[i].title = EngFncs->engine_strdup(_("Required Cluster API Version"));
+        info->info[i].desc =
+		EngFncs->engine_strdup(_("This is the version of the Engine's cluster plug-in API that this plug-in requires.  "
+					 "It will not run on older versions of the Engine's cluster plug-in API."));
         info->info[i].type = EVMS_Type_String;
         snprintf(buffer, 50, "%d.%d.%d",
 		ece_plugin_record.required_plugin_api_version.cluster.major,
 		ece_plugin_record.required_plugin_api_version.cluster.minor,
 	  	ece_plugin_record.required_plugin_api_version.cluster.patchlevel);
-        SET_STRING(info->info[i].value.s, buffer);
+        info->info[i].value.s = EngFncs->engine_strdup(buffer);
         i++;
     } else {
         LOG_ERROR("No support for extra plugin information about \"%s\"\n", info_name);
@@ -2441,7 +2440,7 @@ plugin_record_t ece_plugin_record = {
 				minor:      MINOR_VERSION,
 				patchlevel: PATCH_LEVEL},
 
-	required_engine_api_version: {major:      13,
+	required_engine_api_version: {major:      15,
 				minor:      0,
 				patchlevel: 0},
 
