@@ -539,12 +539,15 @@ boolean md_is_region_active(storage_object_t * region)
 }
 
 
-static boolean mdstat_check_recovery(int mddev_minor)
+boolean mdstat_check_recovery(int mddev_minor, char *status)
 {
 	FILE *fp;
 	char string[256];
 	char mddev_str[10];
 	boolean recovery_running = FALSE;
+	char *p = NULL;
+	unsigned long percent_whole, percent_hundredth, count, total;
+
 
 	LOG_ENTRY();
 
@@ -559,16 +562,26 @@ static boolean mdstat_check_recovery(int mddev_minor)
 					break;
 				if (fgets(string, 256, fp) == NULL)
 					break;
-				if (strstr(string, "recovery"))
+				if ((p = strstr(string, "recovery"))) {
 					recovery_running = TRUE;
-				else if (strstr(string, "resync"))
-						recovery_running = TRUE;
+					p += 8;
+				} else if ((p = strstr(string, "resync"))) {
+					recovery_running = TRUE;
+					p += 6;
+				}
 				
 				/* found mdx, break out of while() loop */
 				break;
 			}
 		}
 		fclose(fp);
+		if (recovery_running && status) {
+			//caller wants status
+			sscanf(p, " =%3lu.%lu%% (%lu/%lu)",
+			       &percent_whole, &percent_hundredth, &count, &total);
+			sprintf(status, " =%3lu.%lu%% (%lu/%lu)",
+				percent_whole, percent_hundredth, count, total);
+		}
 	} else {
 		LOG_WARNING("Could not open /proc/mdstat for reading.\n");
 	}
@@ -578,29 +591,14 @@ static boolean mdstat_check_recovery(int mddev_minor)
 
 boolean md_is_recovery_running(storage_object_t * region)
 {
-	int rc;
 	boolean recovery_running = FALSE;
-	mdu_array_info_t md_info;
 	md_volume_t *vol;
 
 	LOG_ENTRY();
 
-	rc = md_ioctl_get_array_info(region, &md_info);
-	if (rc) {
-		LOG_EXIT_INT(FALSE);
-		return FALSE;
-	}
-
-	recovery_running = (md_info.state & (1<<MD_ARRAY_RECOVERY_RUNNING)) ? TRUE : FALSE;
-	if (recovery_running == FALSE) {
-		/*
-		 * Just in case the kernel does not provide the information
-		 * about resync/recovery, try scanning /proc/mdstat
-		 */
-		vol = (md_volume_t *)region->private_data;
-		recovery_running = mdstat_check_recovery(vol->md_minor);
-	}
-
+	vol = (md_volume_t *)region->private_data;
+	recovery_running = mdstat_check_recovery(vol->md_minor, NULL);
+	
 	LOG_EXIT_INT(recovery_running);
 	return recovery_running;
 }
@@ -669,6 +667,14 @@ int md_fix_dev_major_minor(md_volume_t *vol, boolean do_msg)
 	return 0;
 }
 
+boolean md_get_yes_no_response(char *question)
+{
+	int    answer = 0;
+	char * choice_text[3] = { _("Yes"), _("No"), NULL };
+	QUESTION(&answer, choice_text, question);
+	return (answer == 0) ? TRUE : FALSE;
+}
+
 boolean follow_up_mark_faulty(md_volume_t *volume, storage_object_t *faulty)
 {
 	int    answer = 0;
@@ -809,6 +815,23 @@ md_member_t * md_volume_find_object(md_volume_t *vol, storage_object_t *obj)
 	return NULL;
 }
 
+md_member_t * md_volume_find_member_from_major_minor(md_volume_t *vol, int major, int minor)
+{
+	list_element_t iter;
+	md_member_t *member;
+
+	LOG_ENTRY();
+	LIST_FOR_EACH(vol->members, iter, member) {
+		if ((member->obj->dev_major == major) && 
+		    (member->obj->dev_minor == minor)) {
+			LOG_EXIT_PTR(member);
+			return member;
+		}
+	}
+	LOG_EXIT_PTR(NULL);
+	return NULL;
+}
+
 md_member_t * md_volume_find_member(md_volume_t *vol, int dev_number)
 {
 	list_element_t iter;
@@ -1809,6 +1832,7 @@ int md_volume_remove_faulty_from_active_region(md_volume_t * vol, storage_object
 	evms_md_ioctl_parm_t parm;
 	mdu_disk_info_t info;
 	md_member_t *member;
+	int kernel_idx;
 	
 	LOG_ENTRY();
 	
@@ -1829,7 +1853,6 @@ int md_volume_remove_faulty_from_active_region(md_volume_t * vol, storage_object
 	/*
 	 * Removing a faulty disk which is still in the array
 	 */
-	int kernel_idx;
 	kernel_idx = find_disk_in_active_region(vol->region,
 						faulty->dev_major,
 						faulty->dev_minor);
