@@ -2464,7 +2464,7 @@ static int sb1_read_saved_info(md_member_t *member)
 
 static int sb1_zero_superblock(md_member_t *member, boolean now)
 {
-	mdp_sb_1_t sb;
+	char sb[MD_SB_1_BYTES];
 	
 	LOG_ENTRY();
 	LOG_DEBUG("Removing MD superblock from %s at %"PRIu64".\n",
