@@ -389,8 +389,7 @@ static int mp_compare_targets(md_volume_t *vol,
 	 * that doesn't mean it doesn't exist. :)
 	 */
 	if (strncmp(kernel_pg->selector, MP_SELECTOR, DM_SELECTOR_NAME_SIZE) != 0 ||
-	    kernel_pg->num_paths < vol->nr_disks ||
-	    kernel_pg->num_path_args != 0) {
+	    kernel_pg->num_paths < vol->nr_disks) {
 		goto out;
 	}
 
@@ -813,7 +812,7 @@ static int multipath_create_region(md_volume_t * vol, list_anchor_t output_list,
 
 	LOG_DEBUG("Region consuming child objects\n");
 	LIST_FOR_EACH(vol->members, iter, member) {
-		LOG_DEBUG("Adding object %s to %s region\n", 
+		LOG_DEBUG("Adding object %s to %s region\n",
 			  member->obj->name, vol->name);
 		md_append_region_to_object(region, member->obj);
 	}
@@ -1074,7 +1073,7 @@ static int multipath_create_new_region(md_volume_t * vol, list_anchor_t output_l
 		region->dev_minor = vol->md_minor;
 		vol->region = region;
 		region->flags |= SOFLAG_DIRTY;
-		md_add_object_to_list(region, output_list); 
+		md_add_object_to_list(region, output_list);
 		
 		mp_identify_backup_paths(vol);
 	}
