@@ -117,20 +117,9 @@ static int rep_can_delete(storage_object_t * obj) {
 
 	LOG_ENTRY();
 
-	if (obj->plugin == my_plugin_record) {
-
-		/*
-		 * Only a new replace object, i.e., one that has not been committed yet,
-		 * can be deleted.
-		 */
-		if (!(obj->flags & SOFLAG_NEW)) {
-			LOG_DEBUG("Replace object %s cannot be deleted because it is in progress.\n",
-				  obj->name);
-			rc = EINVAL;
-		}
-
-	} else {
+	if (obj->plugin != my_plugin_record) {
 		LOG_ERROR("%s is not a replace object.  I can't delete it.\n", obj->name);
+		rc = EINVAL;
 	}
 
 	LOG_EXIT_INT(rc);
@@ -270,18 +259,22 @@ static int make_replace_object(storage_object_t   * source,
 					if ((source->flags & (SOFLAG_ACTIVE | SOFLAG_NEEDS_ACTIVATE)) &&
 					     !(source->flags & SOFLAG_NEEDS_DEACTIVATE)) {
 						replace_obj->flags |= SOFLAG_NEEDS_ACTIVATE;
-						if (!(target->flags & SOFLAG_ACTIVE)) {
-							target->flags |= SOFLAG_NEEDS_ACTIVATE;
-						} else if (target->flags & SOFLAG_NEEDS_DEACTIVATE) {
-							target->flags &= ~SOFLAG_NEEDS_DEACTIVATE;
+						if (target != NULL) {
+							if (!(target->flags & SOFLAG_ACTIVE)) {
+								target->flags |= SOFLAG_NEEDS_ACTIVATE;
+							} else if (target->flags & SOFLAG_NEEDS_DEACTIVATE) {
+								target->flags &= ~SOFLAG_NEEDS_DEACTIVATE;
+							}
 						}
 
 					} else {
 						/* Leave replace object inactive. */
-						if (target->flags & SOFLAG_ACTIVE) {
-							target->flags |= SOFLAG_NEEDS_DEACTIVATE;
-						} else if (target->flags & SOFLAG_NEEDS_ACTIVATE) {
-							target->flags &= ~SOFLAG_NEEDS_ACTIVATE;
+						if (target != NULL) {
+							if (target->flags & SOFLAG_ACTIVE) {
+								target->flags |= SOFLAG_NEEDS_DEACTIVATE;
+							} else if (target->flags & SOFLAG_NEEDS_ACTIVATE) {
+								target->flags &= ~SOFLAG_NEEDS_ACTIVATE;
+							}
 						}
 					}
 				}
@@ -316,7 +309,7 @@ static int make_replace_object(storage_object_t   * source,
 						   NULL);
 			if (el == NULL) {
 				LOG_CRITICAL("Error when inserting replace object %s into the parent_list of target object %s.\n",
-					     replace_obj->name, source->name);
+					     replace_obj->name, target->name);
 				rc = ENOMEM;
 			}
 		}
@@ -329,7 +322,7 @@ static int make_replace_object(storage_object_t   * source,
 
 			if (el == NULL) {
 				LOG_CRITICAL("Error when inserting replace object %s into the parent_list of source object %s.\n",
-					     replace_obj->name, target->name);
+					     replace_obj->name, source->name);
 				rc = ENOMEM;
 
 			}
