@@ -400,7 +400,7 @@ static int xfs_expand(logical_volume_t * volume,
 	}
 
 	argv[0] = "xfs_growfs";
-	SET_STRING(argv[1], volume->mount_point);
+	argv[1] = EngFncs->engine_strdup(volume->mount_point);
 	argv[2] = NULL;
 
 	pidf = EngFncs->fork_and_execvp(volume, argv, NULL, fds2, fds2);
@@ -409,7 +409,7 @@ static int xfs_expand(logical_volume_t * volume,
 		while (!(waitpid(pidf, &status, WNOHANG))) {
 			bytes_read = read(fds2[0], buffer, MAX_USER_MESSAGE_LEN);
 			if (bytes_read > 0) {
-				MESSAGE("XFS growfs output: \n%s", buffer);
+				MESSAGE(_("XFS growfs output: \n%s"), buffer);
 				memset(buffer, 0, bytes_read);
 			}
 			usleep(10000);
@@ -418,7 +418,7 @@ static int xfs_expand(logical_volume_t * volume,
 			do {
 				bytes_read = read(fds2[0], buffer, MAX_USER_MESSAGE_LEN);
 				if (bytes_read > 0) {
-					MESSAGE("XFS growfs output: \n%s", buffer);
+					MESSAGE(_("XFS growfs output: \n%s"), buffer);
 				}
 			} while (bytes_read == MAX_USER_MESSAGE_LEN);
 			rc = WEXITSTATUS(status);
@@ -760,10 +760,10 @@ static int get_volume_list(value_list_t ** value_list,
 	/* Increment count to hold the 'None' selection. */
 	count++;
 	/* allocate and populate 'available volumes' list */
-	*value_list = EngFncs->engine_alloc(count * sizeof(value_t) +
+	*value_list = EngFncs->engine_alloc((count + 1) * sizeof(value_t) +
 					    sizeof(value_list_t));
 	i = 0;
-	SET_STRING((*value_list)->value[i].s, NO_SELECTION);
+	(*value_list)->value[i].s = EngFncs->engine_strdup(NO_SELECTION);
 	i++;
 	LIST_FOR_EACH(global_volumes, vol_list_iter, vol) {
 		/* add proper volumes to 'available volumes' list */
@@ -861,15 +861,15 @@ static int xfs_init_task(task_context_t * context)
 
 		if (!xfsutils_support) {
 			int answer = 0;
-			char * choice_text[2] = {"Ok", NULL};
-			EngFncs->user_message(my_plugin_record, &answer, choice_text,
-				"xfsutils were either not found or not at the "
-				"proper version. xfsutils must be version 2.0.0 "
-				"or later to function properly with this FSIM. "
-				"xfsutils must also reside in the search path "
-				"specified by PATH. Please get/install the "
-				"current version of xfsutils from "
-				"http://oss.sgi.com/projects/xfs\n");
+			char * choice_text[2] = {_("Ok"), NULL};
+			QUESTION(&answer, choice_text,
+				 _("xfsutils were either not found or not at the "
+				   "proper version. xfsutils must be version 2.0.0 "
+				   "or later to function properly with this FSIM. "
+				   "xfsutils must also reside in the search path "
+				   "specified by PATH. Please get/install the "
+				   "current version of xfsutils from "
+				   "http://oss.sgi.com/projects/xfs\n"));
 			rc = E_CANCELED;
 			goto out;
 		}
@@ -877,9 +877,9 @@ static int xfs_init_task(task_context_t * context)
 		context->option_descriptors->count = MKFS_XFS_OPTIONS_COUNT;
 
 		/* Set Volume Label option */
-		SET_STRING(option[MKFS_SETVOL_INDEX].name, "vollabel");
-		SET_STRING(option[MKFS_SETVOL_INDEX].title, "Volume Label");
-		SET_STRING(option[MKFS_SETVOL_INDEX].tip, "Set the volume label for the file system.");
+		option[MKFS_SETVOL_INDEX].name = EngFncs->engine_strdup("vollabel");
+		option[MKFS_SETVOL_INDEX].title = EngFncs->engine_strdup(_("Volume Label"));
+		option[MKFS_SETVOL_INDEX].tip = EngFncs->engine_strdup(_("Set the volume label for the file system."));
 		option[MKFS_SETVOL_INDEX].type = EVMS_Type_String;
 		option[MKFS_SETVOL_INDEX].min_len = 1;
 		option[MKFS_SETVOL_INDEX].max_len = LV_NAME_SIZE;
@@ -892,9 +892,9 @@ static int xfs_init_task(task_context_t * context)
 		}
 
 		/* Set Journal Volume option */
-		SET_STRING(option[MKFS_JOURNAL_VOL_INDEX].name, "journalvol");
-		SET_STRING(option[MKFS_JOURNAL_VOL_INDEX].title, "External Journal Volume");
-		SET_STRING(option[MKFS_JOURNAL_VOL_INDEX].tip, "Set the volume for the journal if other than the XFS file system volume.");
+		option[MKFS_JOURNAL_VOL_INDEX].name = EngFncs->engine_strdup("journalvol");
+		option[MKFS_JOURNAL_VOL_INDEX].title = EngFncs->engine_strdup(_("External Journal Volume"));
+		option[MKFS_JOURNAL_VOL_INDEX].tip = EngFncs->engine_strdup(_("Set the volume for the journal if other than the XFS file system volume."));
 		option[MKFS_JOURNAL_VOL_INDEX].type = EVMS_Type_String;
 		option[MKFS_JOURNAL_VOL_INDEX].max_len = EVMS_VOLUME_NAME_SIZE + 1;
 		option[MKFS_JOURNAL_VOL_INDEX].flags = EVMS_OPTION_FLAGS_NOT_REQUIRED |
@@ -909,9 +909,9 @@ static int xfs_init_task(task_context_t * context)
 		}
 
 		/* Log size option */
-		SET_STRING(option[MKFS_SETLOGSIZE_INDEX].name, "logsize");
-		SET_STRING(option[MKFS_SETLOGSIZE_INDEX].title, "Log Size");
-		SET_STRING(option[MKFS_SETLOGSIZE_INDEX].tip, "Set log size (in megabytes). Default log size is 0.4% of volume size. Used only if no external journal volume is specified.");
+		option[MKFS_SETLOGSIZE_INDEX].name = EngFncs->engine_strdup("logsize");
+		option[MKFS_SETLOGSIZE_INDEX].title = EngFncs->engine_strdup(_("Log Size"));
+		option[MKFS_SETLOGSIZE_INDEX].tip = EngFncs->engine_strdup(_("Set log size (in megabytes). Default log size is 0.4% of volume size. Used only if no external journal volume is specified."));
 		option[MKFS_SETLOGSIZE_INDEX].type = EVMS_Type_Real32;
 		option[MKFS_SETLOGSIZE_INDEX].unit = EVMS_Unit_Megabytes;
 		option[MKFS_SETLOGSIZE_INDEX].flags = EVMS_OPTION_FLAGS_NOT_REQUIRED;
@@ -927,9 +927,9 @@ static int xfs_init_task(task_context_t * context)
 		option[MKFS_SETLOGSIZE_INDEX].value.r32 = 4.6;
 
 		/* Force option */
-		SET_STRING(option[MKFS_FORCE_INDEX].name, "force");
-		SET_STRING(option[MKFS_FORCE_INDEX].title, "Force");
-		SET_STRING(option[MKFS_FORCE_INDEX].tip, "Force the mkfs even if XFS thinks the volume has an existing filesystem");
+		option[MKFS_FORCE_INDEX].name = EngFncs->engine_strdup("force");
+		option[MKFS_FORCE_INDEX].title = EngFncs->engine_strdup(_("Force"));
+		option[MKFS_FORCE_INDEX].tip = EngFncs->engine_strdup(_("Force the mkfs even if XFS thinks the volume has an existing filesystem"));
 		option[MKFS_FORCE_INDEX].type = EVMS_Type_Boolean;
 		option[MKFS_FORCE_INDEX].unit = EVMS_Unit_None;
 		option[MKFS_FORCE_INDEX].flags = EVMS_OPTION_FLAGS_NOT_REQUIRED;
@@ -943,15 +943,15 @@ static int xfs_init_task(task_context_t * context)
 	case EVMS_Task_fsck:
 		if (!xfsutils_support) {
 			int answer = 0;
-			char * choice_text[2] = {"Ok", NULL};
-			EngFncs->user_message(my_plugin_record, &answer, choice_text,
-				"xfsutils were either not found or not at the "
-				"proper version. xfsutils must be version 2.0.0 "
-				"or later to function properly with this FSIM. "
-				"xfsutils must also reside in the search path "
-				"specified by PATH. Please get/install the "
-				"current version of xfsutils from "
-				"http://oss.sgi.com/projects/xfs\n");
+			char * choice_text[2] = {_("Ok"), NULL};
+			QUESTION(&answer, choice_text,
+				 _("xfsutils were either not found or not at the "
+				   "proper version. xfsutils must be version 2.0.0 "
+				   "or later to function properly with this FSIM. "
+				   "xfsutils must also reside in the search path "
+				   "specified by PATH. Please get/install the "
+				   "current version of xfsutils from "
+				   "http://oss.sgi.com/projects/xfs\n"));
 			rc = E_CANCELED;
 			goto out;
 		}
@@ -959,17 +959,17 @@ static int xfs_init_task(task_context_t * context)
 		context->option_descriptors->count = FSCK_XFS_OPTIONS_COUNT;
 
 		/* Read-only check option */
-		SET_STRING(option[FSCK_READONLY_INDEX].name, "readonly");
-		SET_STRING(option[FSCK_READONLY_INDEX].title, "Check Read-Only");
-		SET_STRING(option[FSCK_READONLY_INDEX].tip, "Check the file system READ ONLY.  Report but do not correct errors.");
+		option[FSCK_READONLY_INDEX].name = EngFncs->engine_strdup("readonly");
+		option[FSCK_READONLY_INDEX].title = EngFncs->engine_strdup(_("Check Read-Only"));
+		option[FSCK_READONLY_INDEX].tip = EngFncs->engine_strdup(_("Check the file system READ ONLY.  Report but do not correct errors."));
 		option[FSCK_READONLY_INDEX].type = EVMS_Type_Boolean;
 		option[FSCK_READONLY_INDEX].flags = EVMS_OPTION_FLAGS_NOT_REQUIRED;
 		option[FSCK_READONLY_INDEX].value.b = TRUE;
 
 		/* Verbose output option */
-		SET_STRING(option[FSCK_VERBOSE_INDEX].name, "verbose");
-		SET_STRING(option[FSCK_VERBOSE_INDEX].title, "Verbose Output");
-		SET_STRING(option[FSCK_VERBOSE_INDEX].tip, "Log fsck.xfs details and debug information.");
+		option[FSCK_VERBOSE_INDEX].name = EngFncs->engine_strdup("verbose");
+		option[FSCK_VERBOSE_INDEX].title = EngFncs->engine_strdup(_("Verbose Output"));
+		option[FSCK_VERBOSE_INDEX].tip = EngFncs->engine_strdup(_("Log fsck.xfs details and debug information."));
 		option[FSCK_VERBOSE_INDEX].type = EVMS_Type_Boolean;
 		option[FSCK_VERBOSE_INDEX].flags = EVMS_OPTION_FLAGS_NOT_REQUIRED;
 		option[FSCK_VERBOSE_INDEX].value.b = FALSE;
@@ -1111,10 +1111,12 @@ static int xfs_set_volumes(task_context_t * context,
 		/***************************************************
 		 *  TODO - move this volume to unacceptable list   *
 		 ***************************************************/
-		MESSAGE("The size of volume %s is %"PRIu64" bytes. mkfs.xfs "
-			"requires a minimum of %u bytes to build an XFS file "
-			"system.", vol->dev_node,
-			vol->vol_size * EVMS_VSECTOR_SIZE, MINXFS );
+		char number_buffer[64];
+
+		sprintf(number_buffer, "%"PRIu64, vol->vol_size * EVMS_VSECTOR_SIZE );
+		MESSAGE(_("The size of volume %s is %s bytes. mkfs.xfs "
+			  "requires a minimum of %u bytes to build an XFS file system."),
+			vol->dev_node, number_buffer, MINXFS);
 		rc = EPERM;
 		goto out;
 	}
@@ -1216,78 +1218,78 @@ static int xfs_get_volume_info(logical_volume_t * volume,
 
 		Info->count = 10;
 
-		SET_STRING(Info->info[0].name, "MagicNumber");
-		SET_STRING(Info->info[0].title, "XFS Magic Number");
-		SET_STRING(Info->info[0].desc, "XFS Magic Number.");
+		Info->info[0].name = EngFncs->engine_strdup("MagicNumber");
+		Info->info[0].title = EngFncs->engine_strdup(_("XFS Magic Number"));
+		Info->info[0].desc = EngFncs->engine_strdup(_("XFS Magic Number"));
 		Info->info[0].type = EVMS_Type_String;
 		sprintf(magic, "0x%x", xfs_vol->sb->sb_magicnum);
-		SET_STRING(Info->info[0].value.s, magic);
+		Info->info[0].value.s = EngFncs->engine_strdup(magic);
 
-		SET_STRING(Info->info[1].name, "Version");
-		SET_STRING(Info->info[1].title, "XFS SB Version Number");
-		SET_STRING(Info->info[1].desc, "XFS Super Block Version Number.");
+		Info->info[1].name = EngFncs->engine_strdup("Version");
+		Info->info[1].title = EngFncs->engine_strdup(_("XFS Super Block Version Number"));
+		Info->info[1].desc = EngFncs->engine_strdup(_("XFS Super Block Version Number"));
 		Info->info[1].type = EVMS_Type_Unsigned_Int32;
 		Info->info[1].value.ui32 = xfs_vol->sb->sb_versionnum & XFS_SB_VERSION_NUMBITS;
 
-		SET_STRING(Info->info[2].name, "State");
-		SET_STRING(Info->info[2].title, "XFS State");
-		SET_STRING(Info->info[2].desc, "The state of XFS.");
+		Info->info[2].name = EngFncs->engine_strdup("State");
+		Info->info[2].title = EngFncs->engine_strdup(_("XFS State"));
+		Info->info[2].desc = EngFncs->engine_strdup(_("The state of XFS"));
 		Info->info[2].type = EVMS_Type_String;
-		SET_STRING(Info->info[2].value.s,
-			   (xfs_vol->sb->sb_flags == XFS_SBF_READONLY) ?
-			   "ReadOnly" : "None");
+		Info->info[2].value.s =
+			EngFncs->engine_strdup((xfs_vol->sb->sb_flags == XFS_SBF_READONLY) ?
+					       _("ReadOnly") : _("None"));
 
-		SET_STRING(Info->info[3].name, "VolLabel");
-		SET_STRING(Info->info[3].title, "Volume Label");
-		SET_STRING(Info->info[3].desc, "File system volume label chosen via mkfs.xfs.");
+		Info->info[3].name = EngFncs->engine_strdup("VolLabel");
+		Info->info[3].title = EngFncs->engine_strdup(_("Volume Label"));
+		Info->info[3].desc = EngFncs->engine_strdup(_("File system volume label chosen via mkfs.xfs"));
 		Info->info[3].type = EVMS_Type_String;
-		SET_STRING(Info->info[3].value.s, xfs_vol->sb->sb_fname);
+		Info->info[3].value.s = EngFncs->engine_strdup(xfs_vol->sb->sb_fname);
 
 		if (xfs_vol->log_vol) {
-			SET_STRING(Info->info[4].name, "ExtLog");
-			SET_STRING(Info->info[4].title, "External Log Volume");
-			SET_STRING(Info->info[4].desc, "Location of exteral journal");
+			Info->info[4].name = EngFncs->engine_strdup("ExtLog");
+			Info->info[4].title = EngFncs->engine_strdup(_("External Log Volume"));
+			Info->info[4].desc = EngFncs->engine_strdup(_("Location of exteral journal"));
 			Info->info[4].type = EVMS_Type_String;
-			SET_STRING(Info->info[4].value.s, xfs_vol->log_vol->name);
+			Info->info[4].value.s = EngFncs->engine_strdup(xfs_vol->log_vol->name);
 		} else {
-			SET_STRING(Info->info[4].name, "LogSize");
-			SET_STRING(Info->info[4].title, "Inline Log Size");
-			SET_STRING(Info->info[4].desc, "Size of the inline file system log (included in the file system size).");
+			Info->info[4].name = EngFncs->engine_strdup("LogSize");
+			Info->info[4].title = EngFncs->engine_strdup(_("Inline Log Size"));
+			Info->info[4].desc = EngFncs->engine_strdup(_("Size of the inline file system log (included in the file system size)"));
 			Info->info[4].type = EVMS_Type_Unsigned_Int64;
 			Info->info[4].unit = EVMS_Unit_Sectors;
 			Info->info[4].value.ui64 = xfs_vol->sb->sb_logblocks *
 						   (xfs_vol->sb->sb_blocksize / EVMS_VSECTOR_SIZE);
 		}
 
-		SET_STRING(Info->info[5].name, "xfsutils");
-		SET_STRING(Info->info[5].title, "XFS Utilities Version");
-		SET_STRING(Info->info[5].desc, "XFS utilities version number.");
+		Info->info[5].name = EngFncs->engine_strdup("xfsutils");
+		Info->info[5].title = EngFncs->engine_strdup(_("XFS Utilities Version"));
+		Info->info[5].desc = EngFncs->engine_strdup(_("XFS utilities version number"));
 		Info->info[5].type = EVMS_Type_String;
-		SET_STRING(Info->info[5].value.s, xfsutils_version);
+		Info->info[5].value.s = EngFncs->engine_strdup(xfsutils_version);
 
-		SET_STRING(Info->info[6].name, "agcount");
-		SET_STRING(Info->info[6].title, "AG Count");
-		SET_STRING(Info->info[6].desc, "Number of allocation groups");
+		Info->info[6].name = EngFncs->engine_strdup("agcount");
+		Info->info[6].title = EngFncs->engine_strdup(_("Allocation Group Count"));
+		Info->info[6].desc = EngFncs->engine_strdup(_("Number of allocation groups"));
 		Info->info[6].type = EVMS_Type_Unsigned_Int32;
 		Info->info[6].value.ui32 = xfs_vol->sb->sb_agcount;
 
-		SET_STRING(Info->info[7].name, "agsize");
-		SET_STRING(Info->info[7].title, "AG Size");
-		SET_STRING(Info->info[7].desc, "Size of allocation groups");
+		Info->info[7].name = EngFncs->engine_strdup("agsize");
+		Info->info[7].title = EngFncs->engine_strdup(_("Allocation Group Size"));
+		Info->info[7].desc = EngFncs->engine_strdup(_("Size of allocation groups"));
 		Info->info[7].type = EVMS_Type_Unsigned_Int64;
 		Info->info[7].unit = EVMS_Unit_Kilobytes;
 		Info->info[7].value.ui64 = xfs_vol->sb->sb_agblocks * 4;
 
-		SET_STRING(Info->info[8].name, "sunit");
-		SET_STRING(Info->info[8].title, "Stripe Unit");
-		SET_STRING(Info->info[8].desc, "Size of stripe unit");
+		Info->info[8].name = EngFncs->engine_strdup("sunit");
+		Info->info[8].title = EngFncs->engine_strdup(_("Stripe Unit"));
+		Info->info[8].desc = EngFncs->engine_strdup(_("Size of stripe unit"));
 		Info->info[8].type = EVMS_Type_Unsigned_Int32;
 		Info->info[8].unit = EVMS_Unit_Sectors;
 		Info->info[8].value.ui32 = xfs_vol->sb->sb_unit;
 
-		SET_STRING(Info->info[9].name, "swidth");
-		SET_STRING(Info->info[9].title, "Stripe Width");
-		SET_STRING(Info->info[9].desc, "Width of stripe");
+		Info->info[9].name = EngFncs->engine_strdup("swidth");
+		Info->info[9].title = EngFncs->engine_strdup(_("Stripe Width"));
+		Info->info[9].desc = EngFncs->engine_strdup(_("Width of stripe"));
 		Info->info[9].type = EVMS_Type_Unsigned_Int32;
 		Info->info[9].unit = EVMS_Unit_Sectors;
 		Info->info[9].value.ui32 = xfs_vol->sb->sb_width;
@@ -1301,7 +1303,7 @@ static int xfs_get_volume_info(logical_volume_t * volume,
 		}
 
 		Info = EngFncs->engine_alloc(sizeof(extended_info_array_t) +
-					     6 * sizeof(extended_info_t));
+					     5 * sizeof(extended_info_t));
 		if (!Info) {
 			rc = ENOMEM;
 			goto out;
@@ -1309,29 +1311,29 @@ static int xfs_get_volume_info(logical_volume_t * volume,
 
 		Info->count = 5;
 
-		SET_STRING(Info->info[0].name, "LogMagicNumber");
-		SET_STRING(Info->info[0].title, "XFS External Log Magic Number");
-		SET_STRING(Info->info[0].desc, "XFS External Log Magic Number.");
+		Info->info[0].name = EngFncs->engine_strdup("LogMagicNumber");
+		Info->info[0].title = EngFncs->engine_strdup(_("XFS External Log Magic Number"));
+		Info->info[0].desc = EngFncs->engine_strdup(_("XFS External Log Magic Number"));
 		Info->info[0].type = EVMS_Type_String;
 		sprintf(magic, "0x%x", xfs_vol->log_sb->h_magicno);
-		SET_STRING(Info->info[0].value.s, magic);
+		Info->info[0].value.s = EngFncs->engine_strdup(magic);
 
-		SET_STRING(Info->info[1].name, "LogVersion");
-		SET_STRING(Info->info[1].title, "XFS External Log Version Number");
-		SET_STRING(Info->info[1].desc, "XFS External Log Version Number.");
+		Info->info[1].name = EngFncs->engine_strdup("LogVersion");
+		Info->info[1].title = EngFncs->engine_strdup(_("XFS External Log Version Number"));
+		Info->info[1].desc = EngFncs->engine_strdup(_("XFS External Log Version Number"));
 		Info->info[1].type = EVMS_Type_Unsigned_Int32;
 		Info->info[1].value.i32 = xfs_vol->log_sb->h_version;
 
-		SET_STRING(Info->info[2].name, "fsvol");
-		SET_STRING(Info->info[2].title, "Journal for:");
-		SET_STRING(Info->info[2].desc, "Volume for which this is an external log volume");
+		Info->info[2].name = EngFncs->engine_strdup("fsvol");
+		Info->info[2].title = EngFncs->engine_strdup(_("Journal for:"));
+		Info->info[2].desc = EngFncs->engine_strdup(_("Volume for which this is an external log volume"));
 		Info->info[2].type = EVMS_Type_String;
-		SET_STRING(Info->info[2].value.s,
-			   xfs_vol->fs_vol ? xfs_vol->fs_vol->name : "UNKNOWN");
+		Info->info[2].value.s =
+			EngFncs->engine_strdup(xfs_vol->fs_vol ? xfs_vol->fs_vol->name : _("UNKNOWN"));
 
-		SET_STRING(Info->info[3].name, "LogSize");
-		SET_STRING(Info->info[3].title, "Log Size");
-		SET_STRING(Info->info[3].desc, "Size of the file system log (included in the file system size).");
+		Info->info[3].name = EngFncs->engine_strdup("LogSize");
+		Info->info[3].title = EngFncs->engine_strdup(_("Log Size"));
+		Info->info[3].desc = EngFncs->engine_strdup(_("Size of the file system log (included in the file system size)"));
 		Info->info[3].type = EVMS_Type_Unsigned_Int64;
 		Info->info[3].unit = EVMS_Unit_Sectors;
 		if (xfs_vol->fs_vol) {
@@ -1340,11 +1342,11 @@ static int xfs_get_volume_info(logical_volume_t * volume,
 						    EVMS_VSECTOR_SIZE);
 		}
 
-		SET_STRING(Info->info[4].name, "xfsutils");
-		SET_STRING(Info->info[4].title, "XFS Utilities Version");
-		SET_STRING(Info->info[4].desc, "XFS utilities version number.");
+		Info->info[4].name = EngFncs->engine_strdup("xfsutils");
+		Info->info[4].title = EngFncs->engine_strdup(_("XFS Utilities Version"));
+		Info->info[4].desc = EngFncs->engine_strdup(_("XFS utilities version number"));
 		Info->info[4].type = EVMS_Type_String;
-		SET_STRING(Info->info[4].value.s, xfsutils_version);
+		Info->info[4].value.s = EngFncs->engine_strdup(xfsutils_version);
 
 		*info = Info;
 	}
@@ -1379,53 +1381,55 @@ static int xfs_get_plugin_info(char * descriptor_name,
 
 	Info->count = 6;
 
-	SET_STRING(Info->info[0].name, "Short Name");
-	SET_STRING(Info->info[0].title, "Short Name");
-	SET_STRING(Info->info[0].desc, "A short name given to this plugin.");
+	Info->info[0].name = EngFncs->engine_strdup("Short Name");
+	Info->info[0].title = EngFncs->engine_strdup(_("Short Name"));
+	Info->info[0].desc = EngFncs->engine_strdup(_("A short name given to this plug-in"));
 	Info->info[0].type = EVMS_Type_String;
-	SET_STRING(Info->info[0].value.s, my_plugin_record->short_name);
+	Info->info[0].value.s = EngFncs->engine_strdup(my_plugin_record->short_name);
 
-	SET_STRING(Info->info[1].name, "Long Name");
-	SET_STRING(Info->info[1].title, "Long Name");
-	SET_STRING(Info->info[1].desc, "A long name given to this plugin.");
+	Info->info[1].name = EngFncs->engine_strdup("Long Name");
+	Info->info[1].title = EngFncs->engine_strdup(_("Long Name"));
+	Info->info[1].desc = EngFncs->engine_strdup(_("A longer, more descriptive name for this plug-in"));
 	Info->info[1].type = EVMS_Type_String;
-	SET_STRING(Info->info[1].value.s, my_plugin_record->long_name);
+	Info->info[1].value.s = EngFncs->engine_strdup(my_plugin_record->long_name);
 
-	SET_STRING(Info->info[2].name, "Type");
-	SET_STRING(Info->info[2].title, "Plugin Type");
-	SET_STRING(Info->info[2].desc, "There are various types of plugins; each responsible for some kind of storage object.");
+	Info->info[2].name = EngFncs->engine_strdup("Type");
+	Info->info[2].title = EngFncs->engine_strdup(_("Plug-in Type"));
+	Info->info[2].desc = EngFncs->engine_strdup(_("There are various types of plug-ins, each responsible for some kind of storage object or logical volume."));
 	Info->info[2].type = EVMS_Type_String;
-	SET_STRING(Info->info[2].value.s, "File System Interface Module");
+	Info->info[2].value.s = EngFncs->engine_strdup(_("File System Interface Module"));
 
 	sprintf(string, "%d.%d.%d", MAJOR_VERSION, MINOR_VERSION, PATCH_LEVEL);
 
-	SET_STRING(Info->info[3].name, "Version");
-	SET_STRING(Info->info[3].title, "Plugin Version");
-	SET_STRING(Info->info[3].desc, "This is the version number of the plugin.");
+	Info->info[3].name = EngFncs->engine_strdup("Version");
+	Info->info[3].title = EngFncs->engine_strdup(_("Plug-in Version"));
+	Info->info[3].desc = EngFncs->engine_strdup(_("This is the version number of the plug-in."));
 	Info->info[3].type = EVMS_Type_String;
-	SET_STRING(Info->info[3].value.s, string);
+	Info->info[3].value.s = EngFncs->engine_strdup(string);
 
 	sprintf(string, "%d.%d.%d",
 		my_plugin_record->required_engine_api_version.major,
 		my_plugin_record->required_engine_api_version.minor,
 		my_plugin_record->required_engine_api_version.patchlevel);
 
-	SET_STRING(Info->info[4].name, "Required Engine Services API Version");
-	SET_STRING(Info->info[4].title, "Required Engine Services API Version");
-	SET_STRING(Info->info[4].desc, "This is the version of the Engine services that this plug-in requires. It will not run on older versions of the Engine services.");
+	Info->info[4].name = EngFncs->engine_strdup("Required Engine Services Version");
+	Info->info[4].title = EngFncs->engine_strdup(_("Required Engine Services Version"));
+	Info->info[4].desc = EngFncs->engine_strdup(_("This is the version of the Engine services that this plug-in requires.  "
+						      "It will not run on older versions of the Engine services."));
 	Info->info[4].type = EVMS_Type_String;
-	SET_STRING(Info->info[4].value.s, string);
+	Info->info[4].value.s = EngFncs->engine_strdup(string);
 
 	sprintf(string, "%d.%d.%d",
 		my_plugin_record->required_plugin_api_version.fsim.major,
 		my_plugin_record->required_plugin_api_version.fsim.minor,
 		my_plugin_record->required_plugin_api_version.fsim.patchlevel);
 
-	SET_STRING(Info->info[5].name, "Required Engine FSIM API Version");
-	SET_STRING(Info->info[5].title, "Required Engine FSIM API Version");
-	SET_STRING(Info->info[5].desc, "This is the version of the Engine FSIM API that this plug-in requires. It will not run on older versions of the Engine FSIM API.");
+	Info->info[5].name = EngFncs->engine_strdup("Required Engine FSIM API Version");
+	Info->info[5].title = EngFncs->engine_strdup(_("Required Engine FSIM API Version"));
+	Info->info[5].desc = EngFncs->engine_strdup(_("This is the version of the Engine FSIM API that this plug-in requires.  "
+						      "It will not run on older versions of the Engine FSIM API."));
 	Info->info[5].type = EVMS_Type_String;
-	SET_STRING(Info->info[5].value.s, string);
+	Info->info[5].value.s = EngFncs->engine_strdup(string);
 
 	*info = Info;
 
@@ -1451,7 +1455,7 @@ static int xfs_can_expand_by(logical_volume_t * volume,
 	} else if (!EngFncs->is_mounted(volume->dev_node, NULL)) {
 		/* If not mounted, can't expand. online only. */
 		rc = EBUSY;
-	} else if (volume->fs_size + *delta > volume->max_fs_size) {
+	} else if (*delta > volume->max_fs_size - volume->fs_size) {
 		*delta = volume->max_fs_size - volume->fs_size;
 	}
 
@@ -1509,13 +1513,13 @@ plugin_record_t xfs_plugin_record = {
 		.patchlevel	= PATCH_LEVEL
 	},
 	.required_engine_api_version = {
-		.major		= 13,
+		.major		= 15,
 		.minor		= 0,
 		.patchlevel	= 0
 	},
 	.required_plugin_api_version = {
 		.fsim = {
-			.major		= 10,
+			.major		= 11,
 			.minor		= 0,
 			.patchlevel	= 0
 		}
