@@ -813,6 +813,11 @@ int main ( int argc, char * argv[])
       }
 #else
 
+      if (Verbose_Mode >= 2) {
+              /* Clear status message from the screen. */
+              Report_Progress("");
+      }
+
       /* Put out our command prompt. */
       My_Printf("EVMS: ");
 
@@ -934,45 +939,54 @@ static void Display_Command_Line_Help( void )
   My_Printf("The EVMS Command Line Interpreter is invoked using the following syntax:\n\n");
 
   Indent_Printf(1, FALSE,
-         "evms [ -c ] [ -d <Debug Level> ] [ -f <Filename> ] [-m <Engine Mode>]"
-                "[ -n <Nodename> ] [ -p ] [ -r <parameter> ] [ -s ] "
-                "[ -v | -v0 | -v1 | -v2 ] [ -h ] [ -rl <parameter> .. <parameter> ]\n\n");
+         "evms [-b] [-c] [-d <debug-level>] [-f <filename>] [-h] [-m <engine-mode>] "
+                "[-n <node>] [-p] [-r <parameter>] [-s] "
+                "[-v[0-2]] [-rl <parameter> ... <parameter>]\n\n");
 
   My_Printf("where:\n");
+  Indent_Printf(1, FALSE,
+         "-b      tells the EVMS CLI to run in batch mode.  "
+                "Any time there is a prompt for input from the user, the default value should be "
+		"accepted automatically. "
+                "This is the default behavior with the -f option.\n");
   Indent_Printf(1, FALSE,
          "-c      indicates that changes are not to be committed to disk until the "
                 "user exits the EVMS Command Line Interpreter.  "
                 "Normally changes are committed to disk after each individual command is completed, "
                 "even when there are multiple commands specified on the same command line.\n");
   Indent_Printf(1, FALSE,
-         "-d      <Debug Level> sets the debug level, which controls how much information "
+         "-d      <debug-level> sets the debug level, which controls how much information "
                 "is logged in the evmsEngine.log file located in /var/log directory.  "
-                "<Debug Level> is either Default, Critical, Serious, Error, Warning,  "
-                "Details, Extra, Entry_Exit, Everything, or Debug.\n");
+                "<debug-level> is either Critical, Serious, Error, Warning, Default, "
+                "Details, Entry_Exit, Debug, Extra, or Everything.\n");
   Indent_Printf(1, FALSE,
-         " -f     <Filename> tells the EVMS Command Line Interpreter to accept input "
-                "from the file specified by <Filename>.  "
-                "When all of the commands in <Filename> have been processed, "
+         "-f      <filename> tells the EVMS Command Line Interpreter to accept input "
+                "from the file specified by <filename>.  "
+                "When all of the commands in <filename> have been processed, "
                 "the EVMS Command Line Interpreter will exit.\n");
   Indent_Printf(1, FALSE,
-         "-m      <Engine Mode> tells the EVMS Command Line Interpreter the mode in which "
+         "-h      displays this help text.  "
+                "To get help on commands accepted by the EVMS Command Line Interpreter, invoke the interpreter, "
+                "enter the word 'help' at the prompt, and press enter.\n");
+  Indent_Printf(1, FALSE,
+         "-m      <engine-mode> tells the EVMS Command Line Interpreter the mode in which "
                 "it should open the EVMS Engine.  "
-                "<Engine Mode> is either ReadOnly, ReadWrite, or Daemon.  "
+                "<engine-mode> is either ReadOnly, ReadWrite, or Daemon.  "
                 "Daemon mode should only be specified when using the Command Line Interpreter "
                 "to start the EVMS Engine daemon on nodes in a cluster.\n");
   Indent_Printf(1, FALSE,
-         "-n      <Nodename> tells the EVMS Command Line Interpreter that all\n"
-                "        commands are intended for the given node name in a cluster.\n");
+         "-n      <node> tells the EVMS Command Line Interpreter that all "
+                "commands are intended for the given node name in a cluster.\n");
   Indent_Printf(1, FALSE,
          "-p      tells the EVMS Command Line Interpreter to parse commands only.  "
                 "Errors found during parsing will be reported.  "
                 "Commands will NOT be executed.\n");
   Indent_Printf(1, FALSE,
-         "-     r tells the EVMS Command Line Interpreter that the next command line "
+         "-r      tells the EVMS Command Line Interpreter that the next command line "
                 "argument is a replacement parameter.  "
-                "See NOTE below.\n");
+                "See examples below.\n");
   Indent_Printf(1, FALSE,
-         " -s     tells the EVMS Command Line Interpreter to prompt for a single command "
+         "-s      tells the EVMS Command Line Interpreter to prompt for a single command "
                 "line, execute the command line, and then exit.  "
                 "The EVMS Command Line Interpreter normally prompts for command lines until it finds an "
                 "empty command line, at which point it exits.\n");
@@ -994,11 +1008,7 @@ static void Display_Command_Line_Help( void )
                 "The messages are displayed using a single line on the screen, i.e., "
                 "the current message is erased and the next message is displayed in its place.\n");
   Indent_Printf(1, FALSE,
-         "-h      displays this help text.  "
-                "To get help on commands accepted by the EVMS Command Line Interpreter, invoke the interpreter, "
-                "enter the word 'help' at the prompt, and press enter.\n");
-  Indent_Printf(1, FALSE,
-         "-rl      tells the EVMS Command Line Interpreter that all of the remaining "
+         "-rl     tells the EVMS Command Line Interpreter that all of the remaining "
                 "command line arguments are replacement parameters.  "
                 "Replacement parameters are accessed in EVMS commands using the $(x) notation, "
                 "where x is a number identifying which replacement parameter to use.  "
@@ -1499,8 +1509,8 @@ static int Map_Command_List_Entries (ADDRESS   Object,
 /* Find the current screen width, then break up the buffer on word boundaries
  * into lines that fit within the screen width and print the lines.
  */
-#define WHITE_SPACE " \t\n"
-#define WHITE_SPACE_NO_NL " \t"
+#define WHITE_SPACE " \t\r\n"
+#define WHITE_SPACE_NO_NL " \t\r"
 
 static int curr_col = 0;
 
@@ -1528,12 +1538,20 @@ static int Marginize(char * string, int indent_level, boolean indent_first_line)
   size_t white_space_size;
   size_t word_size;
   int count;
+  int line_count;
+  int len;
+  int col_width;
+  int col = 0;
+  int i;
 
-  /* Set default column width in case the ioctl fails. */
-  ws.ws_col = 80;
 
   ioctl(1, TIOCGWINSZ, &ws);
 
+  if (ws.ws_col == 0) {
+    /* Set default column width if the ioctl fails. */
+    ws.ws_col = 80;
+  }
+
   if (ws.ws_col < indent_level * 8) {
     return 0;
   }
@@ -1547,25 +1565,22 @@ static int Marginize(char * string, int indent_level, boolean indent_first_line)
 
   /* In order to do indentation there must be extra room in the output buffer
    * for the tabs that are used to indent each line. */
-  if (indent_level > 0) {
-    int line_count = 0;
-    int len = strlen(string);
-    int col_width = ws.ws_col - indent_level * 8;
-    int col = 0;
-    int i;
+  line_count = 0;
+  len = strlen(string);
+  col_width = ws.ws_col - indent_level * 8;
+  col = 0;
 
-    /* Crude line count */
-    for (i = 0; i < len; i++) {
-      col ++;
-      if ((string[i] == '\n') || (col > col_width)) {
-        line_count++;
-        col = 0;
-      }
+  /* Crude line count */
+  for (i = 0; i < len; i++) {
+    col ++;
+    if ((string[i] == '\n') || (col % col_width == 0)) {
+      line_count++;
+      col = 0;
     }
-
-    extra_space = line_count * indent_level;
   }
 
+  extra_space = line_count * (indent_level + 1);
+
   out_buf = malloc(strlen(string) + 1 + extra_space);
   if (out_buf == NULL) {
     return 0;
@@ -1634,11 +1649,14 @@ static int Marginize(char * string, int indent_level, boolean indent_first_line)
 
         switch (*string) {
           case '\n':
-            curr_col = 0;
             /* Add indents if the next character doesn't start a new line. */
             if ((string[1] != '\n') && (string[1] != '\0')) {
               p_out = Do_Indent(p_out, indent_level);
             }
+            /* fall through */
+
+          case '\r':
+            curr_col = 0;
             break;
 
           case '\t':
