@@ -4,19 +4,19 @@
  *
  *   This program is free software;  you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
- *   the Free Software Foundation; either version 2 of the License, or 
+ *   the Free Software Foundation; either version 2 of the License, or
  *   (at your option) any later version.
- * 
+ *
  *   This program is distributed in the hope that it will be useful,
  *   but WITHOUT ANY WARRANTY;  without even the implied warranty of
  *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
  *   the GNU General Public License for more details.
  *
  *   You should have received a copy of the GNU General Public License
- *   along with this program;  if not, write to the Free Software 
+ *   along with this program;  if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
  *
- */ 
+ */
 
 #include <glib.h>
 #include <ncurses.h>
@@ -63,30 +63,6 @@ int filter_shrink(engine_handle_t handle, void *user_data)
 {
 	return evms_can_shrink(handle);
 }
-/**
- *	filter_expand_container - filter containers that can be expanded
- *	@handle: the thing's handle
- *	@user_data: not used
- *
- *	This routine is a standard clist_filter_func function type that checks to see
- *	if the given container can be expanded.
- */
-int filter_expand_container(engine_handle_t handle, void *user_data)
-{
-	return !can_expand_container(handle);
-}
-/**
- *	filter_expand - filter containers that can be shrunk
- *	@handle: the thing's handle
- *	@user_data: not used
- *
- *	This routine is a standard clist_filter_func function type that checks to see
- *	if the given container can be shrunk.
- */
-int filter_shrink_container(engine_handle_t handle, void *user_data)
-{
-	return !can_shrink_container(handle);
-}
 
 /**
  *	format_resize_item - return column strings for a row in the resize selection clist
@@ -106,8 +82,20 @@ int format_resize_item(object_handle_t handle, sector_count_t max_size, GPtrArra
 	rc = evms_get_info(handle, &object);
 	if (rc == 0) {
 		g_ptr_array_add(text, g_strdup(" "));
-		g_ptr_array_add(text, g_strdup(object->info.object.name));
-		g_ptr_array_add(text, make_sectors_readable_string(object->info.object.size));
+		switch (object->type) {
+		case CONTAINER:
+			g_ptr_array_add(text, g_strdup(object->info.container.name));
+			g_ptr_array_add(text, make_sectors_readable_string(object->info.container.size));
+			break;
+		case VOLUME:
+			g_ptr_array_add(text, g_strdup(object->info.volume.name));
+			g_ptr_array_add(text, make_sectors_readable_string(object->info.volume.vol_size));
+			break;
+		default:
+			g_ptr_array_add(text, g_strdup(object->info.object.name));
+			g_ptr_array_add(text, make_sectors_readable_string(object->info.object.size));
+			break;
+		}
 		g_ptr_array_add(text, make_sectors_readable_string(max_size));
 		evms_free(object);
 	}
@@ -317,7 +305,7 @@ struct dialog_window *create_resize_points_dialog(engine_handle_t handle, task_a
 	print_clist_column_title(selwin->clist, 2, _("Size"));
 	print_clist_column_title(selwin->clist, 3, max_min);
 
-	if (action == EVMS_Task_Expand) 
+	if (action == EVMS_Task_Expand)
 		populate_expand_points(selwin->clist, handle);
 	else
 		populate_shrink_points(selwin->clist, handle);
@@ -441,12 +429,9 @@ void show_resize_dialog(object_handle_t handle, task_action_t action,
 	struct dialog_list dialogs;
 	struct dialog_window *dialog;
 	clist_filter_func filter_func;
-	menuitem_activate_cb activate_cb;
+	handle_object_info_t *object = NULL;
 
-	if (action == EVMS_Task_Expand_Container || action == EVMS_Task_Shrink_Container)
-		activate_cb = (menuitem_activate_cb)on_initiate_resize_button_activated;
-	else
-		activate_cb = (menuitem_activate_cb)on_show_resize_points_button_activated;
+	evms_get_info(handle, &object);
 
 	/*
 	 * Allocate a hash table for storing multiple pieces of data needed by the
@@ -459,7 +444,7 @@ void show_resize_dialog(object_handle_t handle, task_action_t action,
 	selwin = create_selection_window(window_title,
 					NULL, NULL,
 					NULL,
-					activate_cb,
+					(menuitem_activate_cb)on_show_resize_points_button_activated,
 					NULL,
 					(menuitem_activate_cb)NULL,
 					hash_table);
@@ -478,12 +463,6 @@ void show_resize_dialog(object_handle_t handle, task_action_t action,
 	case EVMS_Task_Shrink:
 		filter_func = filter_shrink;
 		break;
-	case EVMS_Task_Expand_Container:
-		filter_func = filter_expand_container;
-		break;
-	case EVMS_Task_Shrink_Container:
-		filter_func = filter_shrink_container;
-		break;
 	}
 
 	if (handle == 0)
@@ -646,7 +625,7 @@ int actions_shrink_object_menuitem_activated(struct menu_item *item)
 /**
  *	show_resize_containers_dialog - display one or more containers to start an expand or shrink task
  *	@handle: non-zero when called from context menu to display only that storage container
- *	@action: either EVMS_Task_Shrink_Container or EVMS_Task_Expand_Container
+ *	@action: either EVMS_Task_Shrink or EVMS_Task_Expand
  *
  *	This routine calls the common show_resize_dialog to display the initial container(s) to select
  *	to initiate a shrink or expand task from.
@@ -654,7 +633,7 @@ int actions_shrink_object_menuitem_activated(struct menu_item *item)
 inline void show_resize_containers_dialog(object_handle_t handle, task_action_t action)
 {
 	show_resize_dialog(handle, action,
-			action == EVMS_Task_Expand_Container ? _("Expand Storage Container") :
+			action == EVMS_Task_Expand ? _("Expand Storage Container") :
 						_("Shrink Storage Container"),
 			_("Storage Container"),
 			enum_containers);
@@ -670,7 +649,7 @@ inline void show_resize_containers_dialog(object_handle_t handle, task_action_t
 int context_expand_container_menuitem_activated(struct menu_item *item)
 {
 	show_resize_containers_dialog(GPOINTER_TO_UINT(item->user_data),
-				EVMS_Task_Expand_Container);
+				EVMS_Task_Expand);
 	return 0;
 }
 
@@ -683,7 +662,7 @@ int context_expand_container_menuitem_activated(struct menu_item *item)
  */
 int actions_expand_container_menuitem_activated(struct menu_item *item)
 {
-	show_resize_containers_dialog(0, EVMS_Task_Expand_Container);
+	show_resize_containers_dialog(0, EVMS_Task_Expand);
 	return 0;
 }
 
@@ -697,7 +676,7 @@ int actions_expand_container_menuitem_activated(struct menu_item *item)
 int context_shrink_container_menuitem_activated(struct menu_item *item)
 {
 	show_resize_containers_dialog(GPOINTER_TO_UINT(item->user_data),
-				EVMS_Task_Shrink_Container);
+				EVMS_Task_Shrink);
 	return 0;
 }
 
@@ -710,6 +689,6 @@ int context_shrink_container_menuitem_activated(struct menu_item *item)
  */
 int actions_shrink_container_menuitem_activated(struct menu_item *item)
 {
-	show_resize_containers_dialog(0, EVMS_Task_Shrink_Container);
+	show_resize_containers_dialog(0, EVMS_Task_Shrink);
 	return 0;
 }
