@@ -687,7 +687,8 @@ static int wait_for_path_failure(struct multipath *mp)
 	struct dm_task *task;
 	int rc;
 
-	log_debug("Waiting for path failure on device %s\n", mp->name);
+	log_debug("Waiting for path failure on device %s (event %d)\n",
+		  mp->name, mp->event_nr);
 
 	rc = alloc_dm_task(mp, &task, DM_DEVICE_WAITEVENT);
 	if (rc) {
@@ -915,12 +916,8 @@ static void test_multipath(struct multipath *mp)
 			}
 		} while (mp->num_failed);
 
-		rc = get_info(mp);
-		if (rc) {
-			break;
-		}
-
 		wait_for_path_failure(mp);
+		mp->event_nr++;
 	}
 }
 
